(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      4636,        150]*)
(*NotebookOutlinePosition[      5663,        186]*)
(*  CellTagsIndexPosition[      5589,        180]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["CliffordExpToTrig", "ObjectName",
  CellTags->"Function?"],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  Cell[BoxData[
      \(\(CliffordExpToTrig[lab]\)[expr]\)]],
  "expands the exponentials in expr in terms of Cos and Sin functions. The \
exponentials must be factors of unitary vectors or bivectors with label lab, \
where lab may be also a pair of labels."
}], "Usage",
  CellTags->"Function?"],

Cell[TextData[{
  "See also: ",
  ButtonBox["GeometricPower",
    ButtonData:>{"GeometricPower", None},
    ButtonStyle->"AddOnsLink"],
  ". "
}], "MathCaption"],

Cell[CellGroupData[{

Cell["Examples", "ExampleSection"],

Cell[BoxData[
    \(Needs["\<TCliffordAlgebra1`TClifford`\>"]\)], "Input",
  CellLabel->"In[1]:="],

Cell[BoxData[
    \(SetCliffordBasisValueRules[\[DoubleStruckE], 3]\)], "Input",
  CellLabel->"In[2]:="],

Cell["\<\
If the exponential is made of a pure bivector then we can always expand it in \
terms of Sin and Cos functions\
\>", "Text"],

Cell[BoxData[{
    \(Exp[
      PVector[\[DoubleStruckE]\_1, 1] ** 
          PVector[\[DoubleStruckE]\_2, 
            1] \[Theta]]\), "\[IndentingNewLine]", 
    \(% // 
      CliffordExpToTrig[\[DoubleStruckE]\_1, \[DoubleStruckE]\_2]\)}], "Input",\

  CellLabel->"In[3]:="],

Cell[BoxData[{
    \(Exp[PVector[\[DoubleStruckE]\_1, 1] \[Eta]]\), "\[IndentingNewLine]", 
    \(% // CliffordExpToTrig[\[DoubleStruckE]\_1]\)}], "Input",
  CellLabel->"In[5]:="],

Cell["\<\
But in general we can always perform the following expansion for any clifford \
vector of any order.\
\>", "Text"],

Cell[BoxData[
    \(Exp[
        PVector[\[DoubleStruckE]\_1, 1] ** 
            PVector[\[DoubleStruckE]\_2, 1] \[Theta]] // ExpToTrig\)], "Input",\

  CellLabel->"In[7]:="],

Cell["\<\
The HermitianConjugation is distributed over the exponential argument\
\>", "Text"],

Cell[BoxData[{
    \(Exp[
        PVector[\[DoubleStruckE]\_1, 1] ** 
            PVector[\[DoubleStruckE]\_2, 1] \[Theta]] // 
      SuperDagger\), "\[IndentingNewLine]", 
    \(% // EvaluateSuperDagger\)}], "Input",
  CellLabel->"In[8]:="],

Cell["\<\
The Hermitian conjugation of the exponential of a bivector is its inverse\
\>", "Text"],

Cell[BoxData[{
    \(Exp[
        PVector[\[DoubleStruckE]\_1, 1] ** 
            PVector[\[DoubleStruckE]\_2, 1] \[Theta]] ** 
      SuperDagger[
        Exp[PVector[\[DoubleStruckE]\_1, 1] ** 
              PVector[\[DoubleStruckE]\_2, 
                1] \[Theta]]]\), "\[IndentingNewLine]", 
    \(\(\(% // EvaluateSuperDagger\) // 
        CliffordExpToTrig[\[DoubleStruckE]\_1, \[DoubleStruckE]\_2]\) // 
      CliffordExpToTrig[\[DoubleStruckE]\_2, \[DoubleStruckE]\_1]\), "\
\[IndentingNewLine]", 
    \(% // CliffordExpand\), "\[IndentingNewLine]", 
    \(% // Expand\), "\[IndentingNewLine]", 
    \(% // BasisSimplify[\[DoubleStruckE]]\), "\[IndentingNewLine]", 
    \(% // Simplify\)}], "Input",
  CellLabel->"In[10]:="]
}, Closed]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 800}, {0, 527}},
ScreenStyleEnvironment->"Working",
WindowToolbars->{},
WindowSize->{732, 500},
WindowMargins->{{-2, Automatic}, {Automatic, 0}},
ShowSelection->True,
CommonDefaultFormatTypes->{"Output"->TraditionalForm},
Magnification->1.25,
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Function?"->{
    Cell[1705, 50, 64, 1, 38, "ObjectName",
      CellTags->"Function?"],
    Cell[1772, 53, 339, 8, 56, "Usage",
      CellTags->"Function?"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Function?", 5419, 171}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1705, 50, 64, 1, 38, "ObjectName",
  CellTags->"Function?"],
Cell[1772, 53, 339, 8, 56, "Usage",
  CellTags->"Function?"],
Cell[2114, 63, 161, 6, 36, "MathCaption"],

Cell[CellGroupData[{
Cell[2300, 73, 34, 0, 49, "ExampleSection"],
Cell[2337, 75, 98, 2, 33, "Input"],
Cell[2438, 79, 104, 2, 33, "Input"],
Cell[2545, 83, 134, 3, 29, "Text"],
Cell[2682, 88, 277, 8, 54, "Input"],
Cell[2962, 98, 179, 3, 54, "Input"],
Cell[3144, 103, 124, 3, 29, "Text"],
Cell[3271, 108, 174, 5, 33, "Input"],
Cell[3448, 115, 93, 2, 29, "Text"],
Cell[3544, 119, 241, 6, 54, "Input"],
Cell[3788, 127, 97, 2, 29, "Text"],
Cell[3888, 131, 732, 16, 180, "Input"]
}, Closed]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

