(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      4684,        146]*)
(*NotebookOutlinePosition[      5690,        181]*)
(*  CellTagsIndexPosition[      5616,        175]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["CliffordSimplify", "ObjectName",
  CellTags->"Function?"],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  Cell[BoxData[
      RowBox[{"CliffordSimplify", 
        StyleBox["[",
          "MR"], 
        StyleBox["expr",
          "MR"], 
        StyleBox["]",
          "MR"]}]]],
  " tries to simplify expressions involving the various operations."
}], "Usage",
  CellTags->"Function?"],

Cell["\<\
Clifford Simplify uses WedgeSimplify and GeometricSimplify to simplify \
expressions.\
\>", "MathCaption"],

Cell["\<\
The complete simplification may require the use of  EvaluateSuperDagger and \
EvaluateBarConjugation and CliffordExpand.\
\>", "MathCaption"],

Cell[TextData[{
  "See also:",
  ButtonBox["WedgeSimplify",
    ButtonData:>{"WedgeSimplify", None},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["GeometricPSimplify",
    ButtonData:>{"GeometricPSimplify", None},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["CliffordExpand",
    ButtonData:>{"CliffordExpand", None},
    ButtonStyle->"AddOnsLink"]
}], "MathCaption"],

Cell[CellGroupData[{

Cell["Examples", "ExampleSection"],

Cell[BoxData[
    \(Needs["\<TCliffordAlgebra1`TClifford`\>"]\)], "Input",
  CellLabel->"In[1]:="],

Cell["Let's expand the following expression", "Text"],

Cell[BoxData[
    \(PVector[u, 1] ** \((PVector[v, 1]\[CenterDot]PVector[w, 1])\) - 
      PVector[v, 
          1] ** \((PVector[u, 1]\[CenterDot]PVector[w, 1])\)\)], "Input",
  CellLabel->"In[2]:="],

Cell[BoxData[{
    \(\(Print["\<This is our initial expression:\>"];\)\), "\
\[IndentingNewLine]", 
    \(PVector[u, 1] ** \((PVector[v, 1]\[CenterDot]PVector[w, 1])\) - 
      PVector[v, 
          1] ** \((PVector[u, 1]\[CenterDot]
            PVector[w, 1])\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Expanding the inner product:\>"];\)\), \
"\[IndentingNewLine]", 
    \(\(\(InnerToGeometricP[%%] // CliffordSimplify\) // CliffordExpand\) // 
      Expand\), "\[IndentingNewLine]", 
    \(\(Print["\<Taking the real part. It does not change anything because \
our initial expressionn is real\>"];\)\), "\[IndentingNewLine]", 
    \(\(RealPart[%%] // ExpandRealPart\) // Factor\)}], "Input",
  CellLabel->"In[3]:="],

Cell["Now lets expand the following expression", "Text"],

Cell[BoxData[{
    \(RealPart[
      TakeGrade[PVector[u, 1] ** PVector[v, 1], 2] ** 
        PVector[w, 1]]\), "\[IndentingNewLine]", 
    \(EvaluateTakeGrade[%] // CliffordSimplify\), "\[IndentingNewLine]", 
    \(ExpandRealPart[%]\), "\[IndentingNewLine]", 
    \(CliffordSimplify@CliffordExpand[%]\)}], "Input",
  CellLabel->"In[9]:="],

Cell["The last two results are the same then we conclude:", "Text"],

Cell[BoxData[
    \(RealPart[
        TakeGrade[PVector[u, 1] ** PVector[v, 1], 2] ** PVector[w, 1]] == 
      PVector[u, 1] ** \((PVector[v, 1]\[CenterDot]PVector[w, 1])\) - 
        PVector[v, 
            1] ** \((PVector[u, 1]\[CenterDot]PVector[w, 1])\)\)], "Input",
  CellLabel->"In[13]:="]
}, Closed]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 800}, {0, 527}},
ScreenStyleEnvironment->"Working",
WindowToolbars->{},
WindowSize->{653, 500},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
ShowSelection->True,
CommonDefaultFormatTypes->{"Output"->TraditionalForm},
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Function?"->{
    Cell[1705, 50, 63, 1, 31, "ObjectName",
      CellTags->"Function?"],
    Cell[1771, 53, 326, 12, 32, "Usage",
      CellTags->"Function?"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Function?", 5445, 166}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1705, 50, 63, 1, 31, "ObjectName",
  CellTags->"Function?"],
Cell[1771, 53, 326, 12, 32, "Usage",
  CellTags->"Function?"],
Cell[2100, 67, 116, 3, 31, "MathCaption"],
Cell[2219, 72, 151, 3, 48, "MathCaption"],
Cell[2373, 77, 382, 13, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[2780, 94, 34, 0, 40, "ExampleSection"],
Cell[2817, 96, 98, 2, 29, "Input"],
Cell[2918, 100, 53, 0, 25, "Text"],
Cell[2974, 102, 200, 4, 49, "Input"],
Cell[3177, 108, 721, 14, 169, "Input"],
Cell[3901, 124, 56, 0, 25, "Text"],
Cell[3960, 126, 339, 7, 89, "Input"],
Cell[4302, 135, 67, 0, 25, "Text"],
Cell[4372, 137, 296, 6, 69, "Input"]
}, Closed]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

