(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      7924,        280]*)
(*NotebookOutlinePosition[      8930,        315]*)
(*  CellTagsIndexPosition[      8856,        309]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Geometric Product (**)", "ObjectName",
  CellTags->"Function?"],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  Cell[BoxData[
      RowBox[{"NonCommutativeMultiply", 
        StyleBox["[",
          "MR"], 
        RowBox[{
          StyleBox["p",
            "MR"], 
          StyleBox[",",
            "TI"], 
          StyleBox["q",
            "TI"], 
          StyleBox[",",
            "TI"], 
          StyleBox[" ",
            "TI"], 
          StyleBox[\(r ... \),
            "TI"]}], 
        StyleBox["]",
          "MR"]}]]],
  "represents the geometric product of PVector objects p, q, r..."
}], "Usage",
  CellTags->"Function?"],

Cell[TextData[{
  " The Geometric Product overloads the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " NonCommutativeMultiply (**)"
}], "MathCaption"],

Cell[TextData[{
  "See also: ",
  ButtonBox["GeometricPToWI",
    ButtonData:>{"GeometricPToWI", None},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["WedgeToGeometricP",
    ButtonData:>{"WedgeToGeometricP", None},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["InnerToGeometricP",
    ButtonData:>{"InnerToGeometricP", None},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["PVector",
    ButtonData:>{"PVector"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["CliffordInnerProduct",
    ButtonData:>{"InnerProduct"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["WedgeProduct",
    ButtonData:>{"WedgeProduct", None},
    ButtonStyle->"AddOnsLink"]
}], "MathCaption"],

Cell[CellGroupData[{

Cell["Examples", "ExampleSection"],

Cell[BoxData[
    \(Needs["\<TCliffordAlgebra1`TClifford`\>"]\)], "Input",
  CellLabel->"In[1]:="],

Cell["\<\
The geometric product is introduced using  \"**\" but it is displayed as a \
diamod.  \
\>", "Text"],

Cell[BoxData[
    \(PVector[u] ** PVector[v]\)], "Input",
  CellLabel->"In[2]:="],

Cell["The geometric product is associative", "Text"],

Cell[BoxData[{
    \(\((PVector[u] ** PVector[v])\) ** PVector[w]\), "\[IndentingNewLine]", 
    \(FullForm[%]\)}], "Input",
  CellLabel->"In[3]:="],

Cell["The geometric product is distributed over sum", "Text"],

Cell[BoxData[{
    \(\((PVector[u, 1] + PVector[B, 2])\) ** \((PVector[v, 1] + 
          PVector[F, 2])\)\), "\[IndentingNewLine]", 
    \(% // CliffordExpand\)}], "Input",
  CellLabel->"In[5]:="],

Cell[BoxData[{
    \(\((PVector[u] + PVector[B, 2])\) ** \((PVector[v] + 
          PVector[F, 2])\)\), "\[IndentingNewLine]", 
    \(% // CliffordExpand\)}], "Input",
  CellLabel->"In[7]:="],

Cell["Scalars  are pulled out with GeometricPSimplify", "Text"],

Cell[BoxData[{
    \(PVector[u] ** \((2*PVector[B, 2])\) ** 
      PVector[v]\), "\[IndentingNewLine]", 
    \(% // GeometricPSimplify\)}], "Input",
  CellLabel->"In[9]:="],

Cell[BoxData[{
    \(PVector[u] ** \((Cos[\[Theta]]*PVector[B, 2])\) ** 
      PVector[v]\), "\[IndentingNewLine]", 
    \(% // GeometricPSimplify\)}], "Input",
  CellLabel->"In[11]:="],

Cell["Grade 0 vectors are pulled out too", "Text"],

Cell[BoxData[{
    \(PVector[u] ** \((PVector[B, 0])\) ** 
      PVector[v]\), "\[IndentingNewLine]", 
    \(% // GeometricPSimplify\)}], "Input",
  CellLabel->"In[13]:="],

Cell[BoxData[{
    \(PVector[
        u] ** \((Sin[\[Theta]]*
          PVector[w] ** PVector[v])\)\), "\[IndentingNewLine]", 
    \(% // GeometricPSimplify\)}], "Input",
  CellLabel->"In[15]:="],

Cell[BoxData[{
    \(PVector[u] ** \((Cos[\[Theta]])\)\), "\[IndentingNewLine]", 
    \(% // GeometricPSimplify\)}], "Input",
  CellLabel->"In[17]:="],

Cell["\<\
The geometric product of a first order vector with itself is a scalar.\
\>", "Text"],

Cell[BoxData[{
    \(PVector[u, 1] ** PVector[u, 1]\), "\[IndentingNewLine]", 
    \(% // GeometricPSimplify\)}], "Input",
  CellLabel->"In[19]:="],

Cell["\<\
If the grade is not specified the simplification is not performed.\
\>", "Text"],

Cell[BoxData[{
    \(PVector[u] ** PVector[u]\), "\[IndentingNewLine]", 
    \(% // GeometricPSimplify\)}], "Input",
  CellLabel->"In[21]:="],

Cell[BoxData[{
    \(PVector[u, 1] ** PVector[u, 1] ** 
      PVector[v, 1]\), "\[IndentingNewLine]", 
    \(% // GeometricPSimplify\)}], "Input",
  CellLabel->"In[23]:="],

Cell[BoxData[{
    \(PVector[v, 1] ** PVector[u, 1] ** PVector[u, 1] ** 
      PVector[w, 1]\), "\[IndentingNewLine]", 
    \(% // GeometricPSimplify\)}], "Input",
  CellLabel->"In[25]:="],

Cell["\<\
The wedge product of first grade vectors can be expressed in terms of the \
geometric product.\
\>", "Text"],

Cell[BoxData[{
    \(Wedge[PVector[u, 1], PVector[v, 1]]\), "\[IndentingNewLine]", 
    \(% // WedgeToGeometricP\)}], "Input",
  CellLabel->"In[27]:="],

Cell["\<\
We can expand a wedge product of a vector of first order with other of n \
order.\
\>", "Text"],

Cell[BoxData[{
    \(Wedge[PVector[u, 1], PVector[B, 2]]\), "\[IndentingNewLine]", 
    \(% // WedgeToGeometricP\)}], "Input",
  CellLabel->"In[29]:="],

Cell[BoxData[{
    \(Wedge[PVector[B, 2], PVector[v, 1]]\), "\[IndentingNewLine]", 
    \(% // WedgeToGeometricP\)}], "Input",
  CellLabel->"In[31]:="],

Cell["\<\
Similarly we can expand the inner product into a combination of geometric \
products.\
\>", "Text"],

Cell[BoxData[{
    \(CenterDot[PVector[u, 1], PVector[v, 1]]\), "\[IndentingNewLine]", 
    \(% // InnerToGeometricP\)}], "Input",
  CellLabel->"In[33]:="],

Cell["\<\
We can expand a inner product of a vector of first order with other of n \
order.\
\>", "Text"],

Cell[BoxData[{
    \(CenterDot[PVector[A, 2], PVector[v, 1]]\), "\[IndentingNewLine]", 
    \(% // InnerToGeometricP\)}], "Input",
  CellLabel->"In[35]:="],

Cell["\<\
The geometric product can be expanded as function of the scalar and wedge \
products.\
\>", "Text"],

Cell[BoxData[{
    \(PVector[u, 1] ** PVector[v, 1]\), "\[IndentingNewLine]", 
    \(% // GeometricPToWI\)}], "Input",
  CellLabel->"In[37]:="],

Cell["Now let's make a round trip", "Text"],

Cell[BoxData[{
    \(PVector[u, 1] ** PVector[B, 2]\), "\[IndentingNewLine]", 
    \(% // GeometricPToWI\), "\[IndentingNewLine]", 
    \(\(% // InnerToGeometricP\) // 
      WedgeToGeometricP\), "\[IndentingNewLine]", 
    \(% // Expand\)}], "Input",
  CellLabel->"In[39]:="]
}, Closed]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 800}, {0, 527}},
ScreenStyleEnvironment->"Working",
WindowToolbars->{},
WindowSize->{653, 500},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
ShowSelection->True,
CommonDefaultFormatTypes->{"Output"->TraditionalForm},
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Function?"->{
    Cell[1705, 50, 69, 1, 31, "ObjectName",
      CellTags->"Function?"],
    Cell[1777, 53, 577, 23, 32, "Usage",
      CellTags->"Function?"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Function?", 8685, 300}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1705, 50, 69, 1, 31, "ObjectName",
  CellTags->"Function?"],
Cell[1777, 53, 577, 23, 32, "Usage",
  CellTags->"Function?"],
Cell[2357, 78, 162, 5, 31, "MathCaption"],
Cell[2522, 85, 699, 25, 48, "MathCaption"],

Cell[CellGroupData[{
Cell[3246, 114, 34, 0, 40, "ExampleSection"],
Cell[3283, 116, 98, 2, 29, "Input"],
Cell[3384, 120, 110, 3, 25, "Text"],
Cell[3497, 125, 81, 2, 29, "Input"],
Cell[3581, 129, 52, 0, 25, "Text"],
Cell[3636, 131, 148, 3, 49, "Input"],
Cell[3787, 136, 61, 0, 25, "Text"],
Cell[3851, 138, 197, 4, 49, "Input"],
Cell[4051, 144, 191, 4, 49, "Input"],
Cell[4245, 150, 63, 0, 25, "Text"],
Cell[4311, 152, 172, 4, 49, "Input"],
Cell[4486, 158, 185, 4, 49, "Input"],
Cell[4674, 164, 50, 0, 25, "Text"],
Cell[4727, 166, 171, 4, 49, "Input"],
Cell[4901, 172, 195, 5, 49, "Input"],
Cell[5099, 179, 150, 3, 49, "Input"],
Cell[5252, 184, 94, 2, 25, "Text"],
Cell[5349, 188, 147, 3, 49, "Input"],
Cell[5499, 193, 90, 2, 25, "Text"],
Cell[5592, 197, 141, 3, 49, "Input"],
Cell[5736, 202, 171, 4, 49, "Input"],
Cell[5910, 208, 188, 4, 49, "Input"],
Cell[6101, 214, 118, 3, 25, "Text"],
Cell[6222, 219, 151, 3, 49, "Input"],
Cell[6376, 224, 105, 3, 25, "Text"],
Cell[6484, 229, 151, 3, 49, "Input"],
Cell[6638, 234, 151, 3, 49, "Input"],
Cell[6792, 239, 109, 3, 25, "Text"],
Cell[6904, 244, 155, 3, 49, "Input"],
Cell[7062, 249, 105, 3, 25, "Text"],
Cell[7170, 254, 155, 3, 49, "Input"],
Cell[7328, 259, 109, 3, 25, "Text"],
Cell[7440, 264, 143, 3, 49, "Input"],
Cell[7586, 269, 43, 0, 25, "Text"],
Cell[7632, 271, 276, 6, 89, "Input"]
}, Closed]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

