(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     13731,        393]*)
(*NotebookOutlinePosition[     14462,        418]*)
(*  CellTagsIndexPosition[     14418,        414]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Lorentz Force Equation", "Title"],

Cell[TextData[{
  StyleBox["By Renan Cabrera\n",
    FontSize->18],
  StyleBox["Graduate student\nPhysics Dept., University of Windsor\nWindsor, \
ON, Canada N9B 3P4\nrencabla@ceibo.entelnet.bo\ncabrer7@uwindsor.ca\n\
December/2003",
    FontSize->14]
}], "Subtitle"],

Cell[BoxData[
    \(Needs["\<TCliffordAlgebra1`TClifford`\>"]\)], "Input"],

Cell[BoxData[
    \(DeclareBaseIndices[{0, 1, 2, 3}]\)], "Input"],

Cell["Initial Setting", "Text"],

Cell[BoxData[{
    \(SetCliffordBasisValueRules[\[DoubleStruckE], 
      3]\), "\[IndentingNewLine]", 
    \(SetParavectorBasisValues[\[DoubleStruckE], 
      Length@BaseIndices]\), "\[IndentingNewLine]", 
    \(\(labs = {x, \[Delta], 
          g, \[CapitalGamma]};\)\), "\[IndentingNewLine]", 
    \(DefineTensorShortcuts[{{x, B}, 1}, {F, 2}]\), "\[IndentingNewLine]", 
    \(SetAttributes[c, Constant]\)}], "Input"],

Cell[CellGroupData[{

Cell["Lorentz-Force ", "Section"],

Cell[TextData[{
  "The covariant form of the Lorentz force is:\n\n\t\t\t\t\t\t",
  Cell[BoxData[
      FormBox[
        TagBox[
          StyleBox[
            RowBox[{
              FormBox[
                StyleBox[
                  FractionBox[
                    InterpretationBox[
                      
                      RowBox[{"\<\"\[DifferentialD]\"\>", "\[InvisibleSpace]",
                         
                        FormBox[
                          TagBox[
                            StyleBox[
                              InterpretationBox["p",
                                SequenceForm[ p],
                                Editable->False],
                              FontColor->RGBColor[0, 0, 0.996109]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              0, 0, .99610900000000002]]&)],
                          "TraditionalForm"]}],
                      SequenceForm[ "\[DifferentialD]", 
                        PVector[ p]],
                      Editable->False], 
                    InterpretationBox[
                      
                      InterpretationBox[\("\[DifferentialD]"\[InvisibleSpace]\
t\),
                        SequenceForm[ "\[DifferentialD]", t],
                        Editable->False],
                      SequenceForm[ 
                        SequenceForm[ "\[DifferentialD]", t]],
                      Editable->False]],
                  FontSize->18],
                "TraditionalForm"], "=", 
              FormBox[
                TagBox[
                  SubscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                      RowBox[{"q", " ", 
                        FormBox[
                          RowBox[{
                            FormBox[
                              TagBox[
                                StyleBox[
                                  InterpretationBox["F",
                                    SequenceForm[ F],
                                    Editable->False],
                                  FontColor->RGBColor[0, 0, 0.996109]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  0, 0, .99610900000000002]]&)],
                              "TraditionalForm"], "\[Diamond]", 
                            FormBox[
                              TagBox[
                                StyleBox[
                                  InterpretationBox["u",
                                    SequenceForm[ u],
                                    Editable->False],
                                  FontColor->RGBColor[0.589853, 0, 0.292973],
                                  Magnification->1],
                                (
                                StyleForm[ #, FontColor -> 
                                  RGBColor[ .58985299999999996, 
                                    0, .29297299999999998], Magnification -> 
                                  1.0]&)],
                              "TraditionalForm"]}],
                          "TraditionalForm"]}], "\[RightAngleBracket]"}], 
                    "\[ScriptCapitalR]"],
                  DisplayForm],
                "TraditionalForm"]}],
            FontFamily->"Courier",
            FontSize->16],
          (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
        TraditionalForm]],
    TextAlignment->Center,
    TextJustification->0,
    FontSize->16]
}], "EmphasisText",
  TextAlignment->Left,
  TextJustification->0],

Cell[BoxData[
    \(TotalD[PVector[p], t] \[Equal] \ 
      RealPart[q*PVector[F, {2, 3}] ** PVector[u, {0, 1}]]\)], "Input"],

Cell["\<\
Let's check the right side of the Lorentz force with the Electromagnetic \
field written in terms of the electric and magnetic fields\
\>", "Text"],

Cell[BoxData[{
    \(\ RealPart[
      q*\((PVector["\<E\>", 1] + 
              I*c*PVector[B, 1])\) ** \((\[Gamma] \((1 + 
                  PVector[v, 1]/c)\))\)]\), "\[IndentingNewLine]", 
    \(step = \(\(\(% // ExpandRealPart\) // CliffordExpand\) // 
          CliffordExpand\) // CliffordSimplify\), "\[IndentingNewLine]", 
    \(% //. {\[IndentingNewLine]\ 
        a_*PVector["\<E\>", 1] ** PVector[v, 1] + 
            a_*PVector[v, 1] ** PVector["\<E\>", 1] \[Rule] 
          2*a*PVector[v, 1]\[CenterDot]
              PVector["\<E\>", 1], \[IndentingNewLine]\ \ q*\[Gamma]*
              Complex[0, Rational[1, 2]]*PVector[B, 1] ** PVector[v, 1] + 
            q*\[Gamma]*Complex[0, Rational[\(-1\), 2]]*
              PVector[v, 1] ** PVector[B, 1] \[Rule] 
          q*\[Gamma]*
            PVector[v, 1]\[Cross]
              PVector[B, 1]\[IndentingNewLine]}\)}], "Input"],

Cell[TextData[StyleBox["Note.- The variable step stores the step involving \
only geometric products",
  FontSlant->"Italic"]], "Text"],

Cell["\<\
Splitting the previous result into its scalar and vector part we get:\
\>", "Text"],

Cell[BoxData[{
    \({ExpandScalarPart@ScalarPart[step], 
      ExpandVectorPart@VectorPart[step]}\), "\[IndentingNewLine]", 
    \(% //. {\[IndentingNewLine]\ 
        a_*PVector["\<E\>", 1] ** PVector[v, 1] + 
            a_*PVector[v, 1] ** PVector["\<E\>", 1] \[Rule] 
          2*a*PVector[v, 1]\[CenterDot]
              PVector["\<E\>", 1], \[IndentingNewLine]\ \ q*\[Gamma]*
              Complex[0, Rational[1, 2]]*PVector[B, 1] ** PVector[v, 1] + 
            q*\[Gamma]*Complex[0, Rational[\(-1\), 2]]*
              PVector[v, 1] ** PVector[B, 1] \[Rule] 
          q*\[Gamma]*
            PVector[v, 1]\[Cross]
              PVector[B, 1]\[IndentingNewLine]}\)}], "Input"],

Cell["\<\
where we realize that the scalar part is associated to the work per unit of \
time performed by the Electromagnetic field and the vector part is just the \
traditional Lorentz force equation times \[Gamma].\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Spinorial Form of Lorentz Force", "Section"],

Cell[TextData[{
  "The eigenspinor denoted by ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalLambda]\)]],
  " is just the \"Lorentz Transformation\" that transforms the position of \
the particle from its rest frame to the moving frame that involves \
translations and rotations in general\n \t\t\t\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{"x", "=", 
          RowBox[{
            StyleBox["\[CapitalLambda]",
              FontColor->RGBColor[0, 0, 1]], " ", \(x\_rest\), 
            StyleBox[\(\[CapitalLambda]\^\[Dagger]\),
              FontColor->RGBColor[0, 0, 1]]}]}], TraditionalForm]]],
  " "
}], "EmphasisText"],

Cell[TextData[{
  "The eigenspinor can be used as replacement to store the information of the \
particle.Actually the eigenspinor stores more information because the \
operation to recover the proper velocity \t\t\t\t\t\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{"u", "=", 
          StyleBox[\(\[CapitalLambda]\[CapitalLambda]\^\[Dagger]\),
            FontColor->RGBColor[0, 0, 1]]}], TraditionalForm]]]
}], "EmphasisText"],

Cell[TextData[{
  "The electromagneticfield can be considered as the space rotation rate at \
which the eigensipnor of the particle rotates:\n\t\t\t\t ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox[\(\[DoubleStruckD]\/\(\[DoubleStruckD]\ \[Tau]\)\),
              FontSize->18], 
            StyleBox["\[CapitalLambda]",
              FontSize->16,
              FontColor->RGBColor[0, 0, 1]]}], 
          StyleBox["=",
            FontSize->18], 
          RowBox[{
            StyleBox[\(q\/\(2\ m\ c\)\),
              FontSize->18], 
            StyleBox["F",
              FontSize->18], 
            StyleBox[" ",
              FontSize->18], 
            SuperscriptBox[
              StyleBox["\[CapitalLambda]",
                FontSize->16,
                FontColor->RGBColor[0, 0, 1]], " "]}]}], TraditionalForm]]],
  "\n\nThis equation ctually presents many advantages when we have to solve a \
particular problem."
}], "EmphasisText"],

Cell[CellGroupData[{

Cell["Particle in a constant Electric Field", "Subsection"],

Cell["\<\
If the electromagnetic field is just a constant electric field the solution \
of the eigenspinor equation is readly solved. \
\>", "Text"],

Cell["The eigenspinor solution is:", "Text"],

Cell[BoxData[
    \(PVector[\[CapitalLambda]] -> 
      Exp[1/2*q*\(\[Tau]/m\)/c*PVector["\<E\>", 1]] 
        PVector[\[CapitalLambda]\_0]\)], "Input"],

Cell["\<\
If the particle is released from rest the proper velocity is:\
\>", "Text"],

Cell[BoxData[
    \(PVector[u, {0, 1}] -> 
      Exp[q*\(\[Tau]/m\)/c*PVector["\<E\>", 1]]\)], "Input"],

Cell[TextData[{
  "Recalling that  ",
  Cell[BoxData[
      FormBox[
        TagBox[
          RowBox[{
            StyleBox[
              FormBox[
                TagBox[
                  StyleBox[
                    InterpretationBox["u",
                      SequenceForm[ u],
                      Editable->False],
                    FontColor->RGBColor[0.589853, 0, 0.292973],
                    Magnification->1],
                  (
                  StyleForm[ #, FontColor -> 
                    RGBColor[ .58985299999999996, 0, .29297299999999998], 
                    Magnification -> 1.0]&)],
                "TraditionalForm"],
              FontFamily->"Courier",
              FontSize->16], 
            StyleBox["=",
              FontFamily->"Courier",
              FontSize->16], 
            RowBox[{
              StyleBox["\[Gamma]",
                FontFamily->"Courier",
                FontSize->16], 
              StyleBox[" ",
                FontFamily->"Courier",
                FontSize->16], 
              RowBox[{"(", 
                StyleBox[
                  RowBox[{"1", "+", 
                    FractionBox[
                      RowBox[{" ", 
                        StyleBox["v",
                          FontColor->RGBColor[0, 0, 1]], " "}], "c"]}],
                  FontFamily->"Courier",
                  FontSize->16], 
                StyleBox[")",
                  FontFamily->"Courier",
                  FontSize->16]}]}]}],
          (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
        TraditionalForm]]],
  "we can recover the velocity of the particle in the laboratory frame."
}], "Text"],

Cell[BoxData[
    \(PVector[v, 1] \[Rule] 
      c*VectorPart[PVector[u, {0, 1}]]/
          ScalarPart[PVector[u, {0, 1}]]\)], "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Reference", "Section"],

Cell[TextData[{
  StyleBox["William Baylis, ",
    FontSize->16],
  StyleBox["Electrodynamics. ",
    FontSize->16,
    FontSlant->"Italic"],
  StyleBox["A Modern Geometric Approach, ",
    FontSize->16,
    FontSlant->"Italic"],
  StyleBox["Birkhauser",
    FontSize->16,
    FontVariations->{"CompatibilityType"->0}],
  StyleBox[", 2002.",
    FontSize->16]
}], "Text"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 800}, {0, 527}},
AutoGeneratedPackage->None,
WindowToolbars->{},
WindowSize->{697, 500},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
StyleDefinitions -> "TensorialStyle.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 39, 0, 76, "Title"],
Cell[1769, 54, 267, 7, 147, "Subtitle"],
Cell[2039, 63, 74, 1, 46, "Input"],
Cell[2116, 66, 65, 1, 46, "Input"],
Cell[2184, 69, 31, 0, 34, "Text"],
Cell[2218, 71, 418, 8, 126, "Input"],

Cell[CellGroupData[{
Cell[2661, 83, 33, 0, 61, "Section"],
Cell[2697, 85, 3606, 84, 94, "EmphasisText"],
Cell[6306, 171, 125, 2, 46, "Input"],
Cell[6434, 175, 157, 3, 54, "Text"],
Cell[6594, 180, 891, 17, 246, "Input"],
Cell[7488, 199, 135, 2, 34, "Text"],
Cell[7626, 203, 93, 2, 34, "Text"],
Cell[7722, 207, 685, 13, 186, "Input"],
Cell[8410, 222, 230, 4, 54, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[8677, 231, 50, 0, 41, "Section"],
Cell[8730, 233, 641, 16, 108, "EmphasisText"],
Cell[9374, 251, 435, 9, 88, "EmphasisText"],
Cell[9812, 262, 993, 27, 135, "EmphasisText"],

Cell[CellGroupData[{
Cell[10830, 293, 59, 0, 49, "Subsection"],
Cell[10892, 295, 148, 3, 54, "Text"],
Cell[11043, 300, 44, 0, 34, "Text"],
Cell[11090, 302, 152, 3, 46, "Input"],
Cell[11245, 307, 85, 2, 34, "Text"],
Cell[11333, 311, 103, 2, 46, "Input"],
Cell[11439, 315, 1674, 47, 36, "Text"],
Cell[13116, 364, 136, 3, 66, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[13301, 373, 28, 0, 41, "Section"],
Cell[13332, 375, 371, 14, 37, "Text"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

