(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     41646,       1029]*)
(*NotebookOutlinePosition[     42404,       1055]*)
(*  CellTagsIndexPosition[     42360,       1051]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[" Maxwell's Equations", "Title"],

Cell[TextData[{
  StyleBox["By Renan Cabrera\n",
    FontSize->18],
  StyleBox["Graduate student\nPhysics Dept., University of Windsor\nWindsor, \
ON, Canada N9B 3P4\nrencabla@ceibo.entelnet.bo\ncabrer7@uwindsor.ca\n\
December/2003",
    FontSize->14]
}], "Subtitle"],

Cell[BoxData[
    \(Needs["\<TCliffordAlgebra1`TClifford`\>"]\)], "Input"],

Cell[BoxData[
    \(DeclareBaseIndices[{0, 1, 2, 3}]\)], "Input"],

Cell["Initial Settting", "Text"],

Cell[BoxData[{
    \(SetCliffordBasisValueRules[\[DoubleStruckE], 
      3]\), "\[IndentingNewLine]", 
    \(SetParavectorBasisValues[\[DoubleStruckE], 
      Length@BaseIndices]\), "\[IndentingNewLine]", 
    \(\(labs = {x, \[Delta], 
          g, \[CapitalGamma]};\)\), "\[IndentingNewLine]", 
    \(DefineTensorShortcuts[{{x, B, A}, 1}, {F, 2}]\)}], "Input"],

Cell[CellGroupData[{

Cell["Spliting the Maxwell Equations", "Section"],

Cell[TextData[{
  "The Maxwell equations ",
  Cell[BoxData[
      FormBox[
        TagBox[
          RowBox[{
            StyleBox[
              RowBox[{
                FormBox[
                  OverscriptBox[
                    FormBox[
                      TagBox[
                        StyleBox[
                          InterpretationBox["\<\"\[PartialD]\"\>",
                            SequenceForm[ "\[PartialD]"],
                            Editable->False],
                          FontColor->RGBColor[0.589853, 0, 0.292973],
                          Magnification->1],
                        (
                        StyleForm[ #, FontColor -> 
                          RGBColor[ .58985299999999996, 
                            0, .29297299999999998], Magnification -> 1.0]&)],
                      "TraditionalForm"], "\<\"_\"\>"],
                  "TraditionalForm"], 
                FormBox[
                  TagBox[
                    StyleBox[
                      InterpretationBox["F",
                        SequenceForm[ F],
                        Editable->False],
                      FontColor->RGBColor[0.250004, 0.500008, 0.500008],
                      Magnification->1],
                    (
                    StyleForm[ #, FontColor -> 
                      RGBColor[ .250004, .50000800000000001, \
.50000800000000001], Magnification -> 1.0]&)],
                  "TraditionalForm"]}],
              FontFamily->"Courier",
              FontSize->16], 
            StyleBox["=",
              FontFamily->"Courier",
              FontSize->16], 
            StyleBox["j",
              FontFamily->"Courier",
              FontSize->16,
              FontColor->RGBColor[0.500008, 0, 0.500008]]}],
          (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
        TraditionalForm]]],
  " written in terms of the gradient and time partial derivative are\n\n ",
  Cell[BoxData[
      FormBox[
        TagBox[
          StyleBox[
            RowBox[{
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    FormBox[
                      TagBox[
                        StyleBox[
                          InterpretationBox["\<\"\[Del]\"\>",
                            SequenceForm[ "\[Del]"],
                            Editable->False],
                          FontColor->RGBColor[0, 0, 0.996109],
                          Magnification->1],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0, 0, .99610900000000002], Magnification -> 1.0]&)],
                      
                      "TraditionalForm"], 
                    "+", \(\(1\/c\) "\[PartialD]"\_"t"\)}], ")"}], 
                RowBox[{"(", 
                  RowBox[{
                    FormBox[
                      TagBox[
                        StyleBox[
                          InterpretationBox["\<\"E\"\>",
                            SequenceForm[ "E"],
                            Editable->False],
                          FontColor->RGBColor[0, 0, 0.996109],
                          Magnification->1],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0, 0, .99610900000000002], Magnification -> 1.0]&)],
                      
                      "TraditionalForm"], "+", 
                    RowBox[{"\[ImaginaryI]", " ", "c", " ", 
                      FormBox[
                        TagBox[
                          StyleBox[
                            InterpretationBox["B",
                              SequenceForm[ B],
                              Editable->False],
                            FontColor->RGBColor[0, 0, 0.996109],
                            Magnification->1],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0, 0, .99610900000000002], Magnification -> 
                            1.0]&)],
                        "TraditionalForm"]}]}], ")"}]}], "=", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    FormBox[
                      TagBox[
                        StyleBox[
                          InterpretationBox["\[Phi]",
                            SequenceForm[ \[Phi]],
                            Editable->False],
                          Magnification->1],
                        (StyleForm[ #, Magnification -> 1]&)],
                      "TraditionalForm"], "-", 
                    FormBox[
                      TagBox[
                        StyleBox[
                          InterpretationBox["J",
                            SequenceForm[ J],
                            Editable->False],
                          FontColor->RGBColor[0, 0, 0.996109],
                          Magnification->1],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0, 0, .99610900000000002], Magnification -> 1.0]&)],
                      
                      "TraditionalForm"]}], ")"}], " ", \(Z\_0\)}]}],
            FontFamily->"Courier",
            FontSize->16],
          (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
        TraditionalForm]]],
  " \n \nand can be expanded in four pieces."
}], "EmphasisText"],

Cell[BoxData[
    \(SetAttributes[c, Constant]\)], "Input"],

Cell[BoxData[{
    \(ME = \((1/c*PVector[Subscript["\<\[PartialD]\>", "\<t\>"], 0] + 
              PVector["\<\[Del]\>", 1])\)[\((PVector["\<E\>", 1] + 
              I*c*PVector[B, 1])\)] \[Equal] 
        Subscript[Z, 
            0]*\((PVector[\[Phi], 0] - 
              PVector[J, 1])\)\), "\[IndentingNewLine]", 
    \(ExpandedME = CliffordOperatorExpand[%]\)}], "Input"],

Cell[TextData[StyleBox["Let's take the real part of the Maxwell equations:", \
"EmphasisText",
  FontColor->RGBColor[0.500008, 0, 0.250004]]], "Text"],

Cell[BoxData[{
    \(RealPart[ExpandedME]\), "\[IndentingNewLine]", 
    \(RealME = \(% // ExpandRealPart\) // ExpandAll\)}], "Input"],

Cell["\<\
Now the scalar and vector part of the Real part give the Gauss and Ampere \
laws respectively.\
\>", "Text"],

Cell[BoxData[
    \({ExpandScalarPart@ScalarPart[RealME], 
        ExpandVectorPart@VectorPart[RealME]} // ExpandAll\)], "Input"],

Cell["\<\
Note.- The differential operator is usually put of the left meaning an action \
on the right, however  a differential operator of the right can be easily \
interpreted as the reversion of the differential operator acting on the left. \
One more thing is neccessary to know here is the scope of the application of \
the differential operator. The package keeps track of the part that is under \
operation.\
\>", "EmphasisText"],

Cell[TextData[StyleBox["Let's take the imaginary part of the Maxwell \
equations:", "EmphasisText",
  FontColor->RGBColor[0.500008, 0, 0.250004]]], "Text"],

Cell[BoxData[{
    \(ImaginaryPart[ExpandedME]\), "\[IndentingNewLine]", 
    \(ImaginaryME = \(% // ExpandImaginaryPart\) // ExpandAll\)}], "Input"],

Cell["\<\
The Scalar and vector part of the imaginary part are the no monopoles law and \
the Faraday law.\
\>", "Text"],

Cell[BoxData[
    \({ExpandScalarPart@ScalarPart[ImaginaryME], 
        ExpandVectorPart@VectorPart[ImaginaryME]} // ExpandAll\)], "Input"],

Cell[CellGroupData[{

Cell["Second Procedure:", "Subsubsection"],

Cell[BoxData[{
    \(ScalarPart[ExpandedME]\), "\[IndentingNewLine]", 
    \(ScalarME = \(% // ExpandScalarPart\) // ExpandAll\)}], "Input"],

Cell[BoxData[
    \({ExpandRealPart@RealPart[ScalarME], 
        ExpandImaginaryPart@ImaginaryPart[ScalarME]} // ExpandAll\)], "Input"],

Cell[BoxData[{
    \(VectorPart[ExpandedME]\), "\[IndentingNewLine]", 
    \(VectorME = \(% // ExpandVectorPart\) // ExpandAll\)}], "Input"],

Cell[BoxData[
    \({ExpandRealPart@RealPart[VectorME], 
        ExpandImaginaryPart@ImaginaryPart[VectorME]} // ExpandAll\)], "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Maxwell Equations in Components", "Section"],

Cell[TextData[{
  "The Faraday biparavector can be expanded in terms of a biparavector basis: \
",
  Cell[BoxData[
      FormBox[
        TagBox[
          StyleBox[
            RowBox[{\(1\/2\), " ", 
              FormBox[
                InterpretationBox[
                  SubsuperscriptBox["F", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          StyleBox["\[Mu]",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)], 
                        "\[InvisibleSpace]", 
                        TagBox[
                          StyleBox["\[Nu]",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)]}],
                      SequenceForm[ 
                        StyleForm[ \[Mu], ShowContents -> False], 
                        StyleForm[ \[Nu], ShowContents -> False]],
                      Editable->False], 
                    InterpretationBox[\(\[Mu]\[InvisibleSpace]\[Nu]\),
                      SequenceForm[ \[Mu], \[Nu]],
                      Editable->False]],
                  Subsuperscript[ F, 
                    SequenceForm[ 
                      StyleForm[ \[Mu], ShowContents -> False], 
                      StyleForm[ \[Nu], ShowContents -> False]], 
                    SequenceForm[ \[Mu], \[Nu]]],
                  Editable->False],
                "TraditionalForm"], " ", 
              FormBox[
                TagBox[
                  SubscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                      FormBox[
                        RowBox[{
                          FormBox[
                            TagBox[
                              StyleBox[
                                
                                InterpretationBox[\(\[DoubleStruckE]\_\[Mu]\),
                                  
                                  SequenceForm[ 
                                    Subscript[ \[DoubleStruckE], \[Mu]]],
                                  Editable->False],
                                FontColor->RGBColor[0.589853, 0, 0.292973],
                                Magnification->1],
                              (
                              StyleForm[ #, FontColor -> 
                                RGBColor[ .58985299999999996, 
                                  0, .29297299999999998], Magnification -> 
                                1.0]&)],
                            "TraditionalForm"], "\[Diamond]", 
                          FormBox[
                            OverscriptBox[
                              FormBox[
                                TagBox[
                                  StyleBox[
                                    
                                    InterpretationBox[\(\[DoubleStruckE]\_\
\[Nu]\),
                                      SequenceForm[ 
                                        Subscript[ \[DoubleStruckE], \[Nu]]],
                                      Editable->False],
                                    FontColor->RGBColor[0.589853, 0, 
                                    0.292973],
                                    Magnification->1],
                                  (
                                  StyleForm[ #, FontColor -> 
                                    RGBColor[ .58985299999999996, 
                                      0, .29297299999999998], Magnification -> 
                                    1.0]&)],
                                "TraditionalForm"], "\<\"_\"\>"],
                            "TraditionalForm"]}],
                        "TraditionalForm"], "\[RightAngleBracket]"}], "V"],
                  DisplayForm],
                "TraditionalForm"]}],
            FontFamily->"Courier",
            FontSize->16],
          (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
        TraditionalForm]]],
  " "
}], "EmphasisText"],

Cell["The right side of the Maxwell equations is:", "Text"],

Cell[BoxData[
    \(RightSideME = \(BarConjugation[PVector["\<\[PartialD]\>", {0, 1}]]\)[\ 
        PVector[F, {1, 2}]]\)], "Input"],

Cell["\<\
The next lines define the expansion of the paravector partial derivative\
\>", "Text"],

Cell[BoxData[
    \(BasisExpandPartialD[{\[DoubleStruckE], 
          x}] = {\[IndentingNewLine]\(\(BarConjugation[
                  PVector["\<\[PartialD]\>", {0, 1}]]\)[
                f_] \[Rule] \((\(PartialD[labs]\)[#, xu[0]] ** 
                    PVector[Subscript[\[DoubleStruckE], 0], 0] + 
                  PVector[Subscript[\[DoubleStruckE], 1], 
                      1] ** \(PartialD[labs]\)[#, xu[1]] + 
                  PVector[Subscript[\[DoubleStruckE], 2], 
                      1] ** \(PartialD[labs]\)[#, xu[2]] + 
                  PVector[Subscript[\[DoubleStruckE], 3], 
                      1] ** \(PartialD[labs]\)[#, xu[3]])\) &\)[
          f], \[IndentingNewLine]\[IndentingNewLine]\(\(PVector["\<\[PartialD]\
\>", {0, 1}]\)[
                f_] \[Rule] \((\(PartialD[labs]\)[#, xu[0]] ** 
                    PVector[Subscript[\[DoubleStruckE], 0], 0] - 
                  PVector[Subscript[\[DoubleStruckE], 1], 
                      1] ** \(PartialD[labs]\)[#, xu[1]] - 
                  PVector[Subscript[\[DoubleStruckE], 2], 
                      1] ** \(PartialD[labs]\)[#, xu[2]] - 
                  PVector[Subscript[\[DoubleStruckE], 3], 
                      1] ** \(PartialD[labs]\)[#, xu[3]])\) &\)[
          f]\[IndentingNewLine]}\)], "Input"],

Cell["The next code defines a biparavector expanded in components", "Text"],

Cell[BoxData[
    \(\(BasisExpandParaBivector[{\[Mu]_, \[Nu]_}, \[DoubleStruckE]_]\)[F_] = 
      Module[{}, \[IndentingNewLine]1/2*Fuu[\[Mu], \[Nu]]*
          VectorPart[
            PVector[Subscript[\[DoubleStruckE], \[Mu]], {0, 1}] ** 
              BarConjugation[
                PVector[
                  Subscript[\[DoubleStruckE], \[Nu]], {0, 
                    1}]]]\[IndentingNewLine]]\)], "Input"],

Cell["The Faraday biparavector expanded in components is:", "Text"],

Cell[BoxData[{
    \(\(BasisExpandParaBivector[{\[Mu], \[Nu]}, \[DoubleStruckE]]\)[
      F]\), "\[IndentingNewLine]", 
    \(\(\(\(\(\((\(% // SumExpansion[{\[Mu], \[Nu]}]\) // 
              BasisSimplify[\[DoubleStruckE]])\) // ExpandVectorPart\) // 
        BasisSimplify[\[DoubleStruckE]]\) // 
      EvaluateBarConjugation\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(ExpandedF = 
      PVector[F, {1, 2}] \[Rule] \ % // 
        SymmetrizeSlots[F, 2, {{\(-1\), {1, 2}}}]\), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "The bar paragradient ",
  Cell[BoxData[
      FormBox[
        TagBox[
          StyleBox[
            RowBox[{
              FormBox[
                OverscriptBox[
                  FormBox[
                    TagBox[
                      StyleBox[
                        InterpretationBox["\<\"\[PartialD]\"\>",
                          SequenceForm[ "\[PartialD]"],
                          Editable->False],
                        FontColor->RGBColor[0.589853, 0, 0.292973],
                        Magnification->1],
                      (
                      StyleForm[ #, FontColor -> 
                        RGBColor[ .58985299999999996, 0, .29297299999999998], 
                        Magnification -> 1.0]&)],
                    "TraditionalForm"], "\<\"_\"\>"],
                "TraditionalForm"], "(", 
              FormBox[
                TagBox[
                  StyleBox[
                    InterpretationBox["F",
                      SequenceForm[ F],
                      Editable->False],
                    FontColor->RGBColor[0.250004, 0.500008, 0.500008],
                    Magnification->1],
                  (
                  StyleForm[ #, FontColor -> 
                    RGBColor[ .250004, .50000800000000001, \
.50000800000000001], Magnification -> 1.0]&)],
                "TraditionalForm"], ")"}],
            FontFamily->"Courier",
            FontSize->16],
          (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
        TraditionalForm]]],
  "operated over the expanded Faraday biparavector is:"
}], "Text"],

Cell[BoxData[{
    \(RightSideME\), "\[IndentingNewLine]", 
    \(\((% /. 
        BasisExpandPartialD[{\[DoubleStruckE], 
            x}])\)\), "\[IndentingNewLine]", 
    \(AA = \((\((% /. ExpandedF)\) /. \(PartialD[_]\)[
              PVector[Subscript[\[DoubleStruckE], _], _], _] \[Rule] 
            0\ )\)\), "\[IndentingNewLine]", 
    \(\(\(% // CliffordExpand\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(RightSideInComponentsME = % // 
        BasisSimplify[\[DoubleStruckE]]\), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "The  scalar and vector part of the real part ",
  Cell[BoxData[
      FormBox[
        TagBox[
          StyleBox[
            FormBox[
              TagBox[
                SubscriptBox[
                  RowBox[{"\[LeftAngleBracket]", 
                    RowBox[{
                      FormBox[
                        OverscriptBox[
                          FormBox[
                            TagBox[
                              StyleBox[
                                InterpretationBox["\<\"\[PartialD]\"\>",
                                  SequenceForm[ "\[PartialD]"],
                                  Editable->False],
                                FontColor->RGBColor[0.589853, 0, 0.292973],
                                Magnification->1],
                              (
                              StyleForm[ #, FontColor -> 
                                RGBColor[ .58985299999999996, 
                                  0, .29297299999999998], Magnification -> 
                                1.0]&)],
                            "TraditionalForm"], "\<\"_\"\>"],
                        "TraditionalForm"], "(", 
                      FormBox[
                        TagBox[
                          StyleBox[
                            InterpretationBox["F",
                              SequenceForm[ F],
                              Editable->False],
                            FontColor->RGBColor[0.250004, 0.500008, 0.500008],
                            
                            Magnification->1],
                          (
                          StyleForm[ #, FontColor -> 
                            RGBColor[ .250004, .50000800000000001, \
.50000800000000001], Magnification -> 1.0]&)],
                        "TraditionalForm"], ")"}], "\[RightAngleBracket]"}], 
                  "\[ScriptCapitalR]"],
                DisplayForm],
              "TraditionalForm"],
            FontFamily->"Courier",
            FontSize->16],
          (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
        TraditionalForm]]],
  " are"
}], "Text"],

Cell[BoxData[{
    \(ExpandRealPart@RealPart[RightSideInComponentsME] // 
      BasisSimplify[\[DoubleStruckE]]\), "\[IndentingNewLine]", 
    \(\(\(% /. {Fuu[0, 1] \[Rule] \(-Tensor["\<E\>", {Void}, {x}]\), 
        Fuu[0, 2] \[Rule] \(-Tensor["\<E\>", {Void}, {y}]\), 
        Fuu[0, 3] \[Rule] \(-Tensor["\<E\>", {Void}, {z}]\), 
        Fuu[1, 2] \[Rule] \(-Bd[z]\), Fuu[1, 3] \[Rule] Bd[y], 
        Fuu[2, 3] \[Rule] \(-Bd[x]\)}\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \({ExpandScalarPart@ScalarPart[%], \[IndentingNewLine]Collect[
        ExpandVectorPart@VectorPart[%], 
        PVector[__]]}\), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "The  scalar and vector part of the real part ",
  Cell[BoxData[
      FormBox[
        TagBox[
          StyleBox[
            FormBox[
              TagBox[
                SubscriptBox[
                  RowBox[{"\[LeftAngleBracket]", 
                    RowBox[{
                      FormBox[
                        OverscriptBox[
                          FormBox[
                            TagBox[
                              StyleBox[
                                InterpretationBox["\<\"\[PartialD]\"\>",
                                  SequenceForm[ "\[PartialD]"],
                                  Editable->False],
                                FontColor->RGBColor[0.589853, 0, 0.292973],
                                Magnification->1],
                              (
                              StyleForm[ #, FontColor -> 
                                RGBColor[ .58985299999999996, 
                                  0, .29297299999999998], Magnification -> 
                                1.0]&)],
                            "TraditionalForm"], "\<\"_\"\>"],
                        "TraditionalForm"], "(", 
                      FormBox[
                        TagBox[
                          StyleBox[
                            InterpretationBox["F",
                              SequenceForm[ F],
                              Editable->False],
                            FontColor->RGBColor[0.250004, 0.500008, 0.500008],
                            
                            Magnification->1],
                          (
                          StyleForm[ #, FontColor -> 
                            RGBColor[ .250004, .50000800000000001, \
.50000800000000001], Magnification -> 1.0]&)],
                        "TraditionalForm"], ")"}], "\[RightAngleBracket]"}], 
                  "\[ScriptCapitalI]"],
                DisplayForm],
              "TraditionalForm"],
            FontFamily->"Courier",
            FontSize->16],
          (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
        TraditionalForm]]],
  "are:"
}], "Text"],

Cell[BoxData[{
    \(ExpandImaginaryPart@ImaginaryPart[RightSideInComponentsME] // 
      BasisSimplify[\[DoubleStruckE]]\), "\[IndentingNewLine]", 
    \(\(\(% /. {Fuu[0, 1] \[Rule] \(-Tensor["\<E\>", {Void}, {x}]\), 
        Fuu[0, 2] \[Rule] \(-Tensor["\<E\>", {Void}, {y}]\), 
        Fuu[0, 3] \[Rule] \(-Tensor["\<E\>", {Void}, {z}]\), 
        Fuu[1, 2] \[Rule] \(-Bd[z]\), Fuu[1, 3] \[Rule] Bd[y], 
        Fuu[2, 3] \[Rule] \(-Bd[x]\)}\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \({\(BasisSimplify[\[DoubleStruckE]]\)[ExpandScalarPart@ScalarPart[%]], 
      Collect[\(BasisSimplify[\[DoubleStruckE]]\)[
          ExpandVectorPart@
            VectorPart[%]], \
\[IndentingNewLine]NonCommutativeMultiply[__]]}\), "\[IndentingNewLine]", 
    \(\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Electromagnetic Potential", "Section"],

Cell[TextData[{
  "The electromagnetic field comes from the vector part of the paragraient of \
the barconjugated of the paravector potential:\n\t\t\t ",
  Cell[BoxData[
      FormBox[
        TagBox[
          StyleBox[
            RowBox[{
              FormBox[
                TagBox[
                  StyleBox[
                    InterpretationBox["F",
                      SequenceForm[ F],
                      Editable->False],
                    FontColor->RGBColor[0.250004, 0.500008, 0.500008],
                    Magnification->1],
                  (
                  StyleForm[ #, FontColor -> 
                    RGBColor[ .250004, .50000800000000001, \
.50000800000000001], Magnification -> 1.0]&)],
                "TraditionalForm"], "=", 
              RowBox[{"c", " ", 
                FormBox[
                  TagBox[
                    SubscriptBox[
                      RowBox[{"\[LeftAngleBracket]", 
                        RowBox[{
                          FormBox[
                            TagBox[
                              StyleBox[
                                InterpretationBox["\<\"\[PartialD]\"\>",
                                  SequenceForm[ "\[PartialD]"],
                                  Editable->False],
                                FontColor->RGBColor[0.589853, 0, 0.292973],
                                Magnification->1],
                              (
                              StyleForm[ #, FontColor -> 
                                RGBColor[ .58985299999999996, 
                                  0, .29297299999999998], Magnification -> 
                                1.0]&)],
                            "TraditionalForm"], "(", 
                          FormBox[
                            OverscriptBox[
                              FormBox[
                                TagBox[
                                  StyleBox[
                                    InterpretationBox["A",
                                      SequenceForm[ A],
                                      Editable->False],
                                    FontColor->RGBColor[0.589853, 0, 
                                    0.292973],
                                    Magnification->1],
                                  (
                                  StyleForm[ #, FontColor -> 
                                    RGBColor[ .58985299999999996, 
                                      0, .29297299999999998], Magnification -> 
                                    1.0]&)],
                                "TraditionalForm"], "\<\"_\"\>"],
                            "TraditionalForm"], ")"}], 
                        "\[RightAngleBracket]"}], "V"],
                    DisplayForm],
                  "TraditionalForm"]}]}],
            FontFamily->"Courier",
            FontSize->16],
          (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
        TraditionalForm]]],
  "=",
  Cell[BoxData[
      FormBox[
        TagBox[
          StyleBox[
            FormBox[
              TagBox[
                RowBox[{" ", 
                  SubscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                      RowBox[{
                        RowBox[{"(", 
                          RowBox[{
                            RowBox[{\(1\/c\), 
                              FormBox[
                                TagBox[
                                  StyleBox[
                                    InterpretationBox[\("\[PartialD]"\_"t"\),
                                      SequenceForm[ 
                                        Subscript[ "\[PartialD]", "t"]],
                                      Editable->False],
                                    Magnification->1],
                                  (StyleForm[ #, Magnification -> 1]&)],
                                "TraditionalForm"]}], "-", 
                            FormBox[
                              TagBox[
                                StyleBox[
                                  InterpretationBox["\<\"\[Del]\"\>",
                                    SequenceForm[ "\[Del]"],
                                    Editable->False],
                                  FontColor->RGBColor[0, 0, 0.996109],
                                  Magnification->1],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  0, 0, .99610900000000002], Magnification -> 
                                  1.0]&)],
                              "TraditionalForm"]}], ")"}], 
                        RowBox[{"(", 
                          RowBox[{
                            FractionBox[
                              FormBox[
                                TagBox[
                                  StyleBox[
                                    InterpretationBox["\[Phi]",
                                      SequenceForm[ \[Phi]],
                                      Editable->False],
                                    Magnification->1],
                                  (StyleForm[ #, Magnification -> 1]&)],
                                "TraditionalForm"], "c"], "-", 
                            FormBox[
                              TagBox[
                                StyleBox[
                                  InterpretationBox["A",
                                    SequenceForm[ A],
                                    Editable->False],
                                  FontColor->RGBColor[0, 0, 0.996109],
                                  Magnification->1],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  0, 0, .99610900000000002], Magnification -> 
                                  1.0]&)],
                              "TraditionalForm"]}], ")"}]}], 
                      "\[RightAngleBracket]"}], "V"]}],
                DisplayForm],
              "TraditionalForm"],
            FontFamily->"Courier",
            FontSize->16],
          (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
        TraditionalForm]]]
}], "EmphasisText"],

Cell[BoxData[
    \(PVector[F, {1, 2}] == 
      c*VectorPart[\(PVector["\<\[PartialD]\>", {0, 1}]\)[\ 
            BarConjugation[PVector[A, {0, 1}]]]]\)], "Input"],

Cell[BoxData[{
    \(VectorPart[\[IndentingNewLine]\((1/c*
              PVector[Subscript["\<\[PartialD]\>", "\<t\>"], 0] - 
            PVector["\<\[Del]\>", 1])\)[\((PVector[\[Phi], 0]/c - 
            PVector[A, 1])\)]\[IndentingNewLine]]\), "\[IndentingNewLine]", 
    \(% // CliffordOperatorExpand\), "\[IndentingNewLine]", 
    \(% // ExpandVectorPart\)}], "Input"],

Cell[CellGroupData[{

Cell["Expansion in components", "Subsection"],

Cell[BoxData[
    \(\(BasisExpandParaBivector[\[Mu]_, \[DoubleStruckE]_]\)[A_] = 
      Module[{}, \[IndentingNewLine]Au[\[Mu]]*
          PVector[Subscript[\[DoubleStruckE], \[Mu]], {0, 
              1}]\[IndentingNewLine]]\)], "Input"],

Cell[BoxData[{
    \(VectorPart[\[IndentingNewLine]\(PVector["\<\[PartialD]\>", {0, 
            1}]\)[\ \ BarConjugation[\ \(BasisExpandParaBivector[\[Mu], \
\[DoubleStruckE]]\)[A]]\ \ ]\[IndentingNewLine]]\), "\[IndentingNewLine]", 
    \(\(% // SumExpansion[{\[Mu]}]\) // 
      BasisSimplify[\[DoubleStruckE]]\), "\[IndentingNewLine]", 
    \(\(\(\(\((% /. 
              BasisExpandPartialD[{\[DoubleStruckE], 
                  x}])\) /. \(PartialD[_]\)[
              PVector[Subscript[\[DoubleStruckE], _], _], _] \[Rule] 0\  // 
        CliffordExpand\) // 
      BasisSimplify[\[DoubleStruckE]]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Collect[\(% // ExpandVectorPart\) // 
        BasisSimplify[\[DoubleStruckE]], {NonCommutativeMultiply[_], 
        PVector[__]}]\), "\[IndentingNewLine]", 
    \(\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Lorenz Gauge Condition", "Subsection"],

Cell[TextData[{
  "The Lorentz gauge condition states:\n\t\t\t\t\t ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          TagBox[
            StyleBox[
              FormBox[
                TagBox[
                  SubscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                      RowBox[{
                        FormBox[
                          TagBox[
                            StyleBox[
                              InterpretationBox["\<\"\[PartialD]\"\>",
                                SequenceForm[ "\[PartialD]"],
                                Editable->False],
                              FontColor->RGBColor[0.589853, 0, 0.292973],
                              Magnification->1],
                            (
                            StyleForm[ #, FontColor -> 
                              RGBColor[ .58985299999999996, 
                                0, .29297299999999998], Magnification -> 
                              1.0]&)],
                          "TraditionalForm"], "(", 
                        FormBox[
                          OverscriptBox[
                            FormBox[
                              TagBox[
                                StyleBox[
                                  InterpretationBox["A",
                                    SequenceForm[ A],
                                    Editable->False],
                                  FontColor->RGBColor[0.589853, 0, 0.292973],
                                  Magnification->1],
                                (
                                StyleForm[ #, FontColor -> 
                                  RGBColor[ .58985299999999996, 
                                    0, .29297299999999998], Magnification -> 
                                  1.0]&)],
                              "TraditionalForm"], "\<\"_\"\>"],
                          "TraditionalForm"], ")"}], "\[RightAngleBracket]"}],
                     "S"],
                  DisplayForm],
                "TraditionalForm"],
              FontFamily->"Courier",
              FontSize->16],
            (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], "=", 
          " ", "0"}], TraditionalForm]]]
}], "Text"],

Cell["Expanding we obtain the traditional form", "Text"],

Cell[BoxData[{
    \(ScalarPart[\(PVector["\<\[PartialD]\>", {0, 1}]\)[\ 
        BarConjugation[PVector[A, {0, 1}]]]]\), "\[IndentingNewLine]", 
    \(% /. \ {PVector["\<\[PartialD]\>", {0, 
              1}] -> \((1/c*
                PVector[Subscript["\<\[PartialD]\>", "\<t\>"], 0] - 
              PVector["\<\[Del]\>", 1])\), 
        PVector[A, {0, 1}] -> \((PVector[\[Phi], 0]/c + 
              PVector[A, 1])\)}\), "\[IndentingNewLine]", 
    \(\(% // EvaluateBarConjugation\) // 
      CliffordOperatorExpand\), "\[IndentingNewLine]", 
    \(\(% // FullEvaluateBarConjugation\) // 
      CliffordExpand\), "\[IndentingNewLine]", 
    \(% // ExpandScalarPart\)}], "Input"],

Cell["\<\
An equivalent form with the bar conjugation over the partial derivative:\
\>", "Text"],

Cell[BoxData[{
    \(ScalarPart[\(BarConjugation[PVector["\<\[PartialD]\>", {0, 1}]]\)[\ 
        PVector[A, {0, 1}]]]\), "\[IndentingNewLine]", 
    \(% /. \ {PVector["\<\[PartialD]\>", {0, 
              1}] -> \((1/c*
                PVector[Subscript["\<\[PartialD]\>", "\<t\>"], 0] - 
              PVector["\<\[Del]\>", 1])\), 
        PVector[A, {0, 1}] -> \((PVector[\[Phi], 0]/c + 
              PVector[A, 1])\)}\), "\[IndentingNewLine]", 
    \(% // FullEvaluateBarConjugation\), "\[IndentingNewLine]", 
    \(% // CliffordOperatorExpand\), "\[IndentingNewLine]", 
    \(% // ExpandScalarPart\)}], "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Energy and Momentum", "Section"],

Cell[TextData[{
  "The following expression has units of a flux of energy per unit of volume\n\
\t",
  Cell[BoxData[
      FormBox[
        TagBox[
          StyleBox[
            RowBox[{\(1\/2\), " ", \(\[Epsilon]\_0\), "c", " ", 
              FormBox[
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{
                      FormBox[
                        TagBox[
                          StyleBox[
                            InterpretationBox["\<\"E\"\>",
                              SequenceForm[ "E"],
                              Editable->False],
                            FontColor->RGBColor[0, 0, 0.996109],
                            Magnification->1],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0, 0, .99610900000000002], Magnification -> 
                            1.0]&)],
                        "TraditionalForm"], "+", 
                      RowBox[{"\[ImaginaryI]", " ", "c", " ", 
                        FormBox[
                          TagBox[
                            StyleBox[
                              InterpretationBox["B",
                                SequenceForm[ B],
                                Editable->False],
                              FontColor->RGBColor[0, 0, 0.996109],
                              Magnification->1],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              0, 0, .99610900000000002], Magnification -> 
                              1.0]&)],
                          "TraditionalForm"]}]}], ")"}], "\[Diamond]", 
                  SuperscriptBox[
                    RowBox[{"(", 
                      RowBox[{
                        FormBox[
                          TagBox[
                            StyleBox[
                              InterpretationBox["\<\"E\"\>",
                                SequenceForm[ "E"],
                                Editable->False],
                              FontColor->RGBColor[0, 0, 0.996109],
                              Magnification->1],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              0, 0, .99610900000000002], Magnification -> 
                              1.0]&)],
                          "TraditionalForm"], "+", 
                        RowBox[{"\[ImaginaryI]", " ", "c", " ", 
                          FormBox[
                            TagBox[
                              StyleBox[
                                InterpretationBox["B",
                                  SequenceForm[ B],
                                  Editable->False],
                                FontColor->RGBColor[0, 0, 0.996109],
                                Magnification->1],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, .99610900000000002], Magnification -> 
                                1.0]&)],
                            "TraditionalForm"]}]}], ")"}], "\[Dagger]"]}],
                "TraditionalForm"], " "}],
            FontFamily->"Courier",
            FontSize->16],
          (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
        TraditionalForm]]],
  "\nthe scalar part is the energy per unit of volume of th electromagnetic \
field (times c) and the vector part is the energy flux density."
}], "EmphasisText"],

Cell[BoxData[{
    \(c*\[Epsilon]\_0/2 \((PVector["\<E\>", 1] + I*c*PVector[B, 1])\) ** 
        SuperDagger[\((PVector["\<E\>", 1] + 
              I*c*PVector[B, 1])\)]\), "\[IndentingNewLine]", 
    \(\({ScalarPart[%], VectorPart[%]} // EvaluateSuperDagger\) // 
      CliffordExpand\), "\[IndentingNewLine]", 
    \(\(% // ExpandScalarPart\) // ExpandVectorPart\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Reference", "Section"],

Cell[TextData[{
  StyleBox["William Baylis, ",
    FontSize->16],
  StyleBox["Electrodynamics. A Modern Geometric Approach",
    FontSize->16,
    FontSlant->"Italic"],
  StyleBox[", Birkhauser,2002.",
    FontSize->16]
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "Subsubtitle"],

Cell["", "Subsubtitle"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 800}, {0, 527}},
AutoGeneratedPackage->None,
WindowToolbars->{},
WindowSize->{792, 500},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
CellLabelAutoDelete->True,
StyleDefinitions -> "TensorialStyle.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 37, 0, 76, "Title"],
Cell[1767, 54, 267, 7, 147, "Subtitle"],
Cell[2037, 63, 74, 1, 46, "Input"],
Cell[2114, 66, 65, 1, 46, "Input"],
Cell[2182, 69, 32, 0, 34, "Text"],
Cell[2217, 71, 361, 7, 106, "Input"],

Cell[CellGroupData[{
Cell[2603, 82, 49, 0, 61, "Section"],
Cell[2655, 84, 5401, 130, 136, "EmphasisText"],
Cell[8059, 216, 59, 1, 46, "Input"],
Cell[8121, 219, 378, 7, 106, "Input"],
Cell[8502, 228, 150, 2, 34, "Text"],
Cell[8655, 232, 134, 2, 66, "Input"],
Cell[8792, 236, 118, 3, 34, "Text"],
Cell[8913, 241, 129, 2, 66, "Input"],
Cell[9045, 245, 436, 7, 108, "EmphasisText"],
Cell[9484, 254, 155, 2, 34, "Text"],
Cell[9642, 258, 149, 2, 66, "Input"],
Cell[9794, 262, 120, 3, 34, "Text"],
Cell[9917, 267, 139, 2, 66, "Input"],

Cell[CellGroupData[{
Cell[10081, 273, 42, 0, 43, "Subsubsection"],
Cell[10126, 275, 140, 2, 66, "Input"],
Cell[10269, 279, 135, 2, 66, "Input"],
Cell[10407, 283, 140, 2, 66, "Input"],
Cell[10550, 287, 135, 2, 66, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[10734, 295, 50, 0, 41, "Section"],
Cell[10787, 297, 4024, 88, 54, "EmphasisText"],
Cell[14814, 387, 59, 0, 34, "Text"],
Cell[14876, 389, 132, 2, 46, "Input"],
Cell[15011, 393, 96, 2, 34, "Text"],
Cell[15110, 397, 1298, 22, 286, "Input"],
Cell[16411, 421, 75, 0, 34, "Text"],
Cell[16489, 423, 413, 8, 126, "Input"],
Cell[16905, 433, 67, 0, 34, "Text"],
Cell[16975, 435, 545, 11, 146, "Input"],
Cell[17523, 448, 1600, 41, 40, "Text"],
Cell[19126, 491, 554, 12, 166, "Input"],
Cell[19683, 505, 2127, 50, 46, "Text"],
Cell[21813, 557, 671, 12, 186, "Input"],
Cell[22487, 571, 2127, 50, 46, "Text"],
Cell[24617, 623, 785, 14, 206, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[25439, 642, 44, 0, 41, "Section"],
Cell[25486, 644, 6239, 135, 99, "EmphasisText"],
Cell[31728, 781, 165, 3, 66, "Input"],
Cell[31896, 786, 372, 6, 146, "Input"],

Cell[CellGroupData[{
Cell[32293, 796, 45, 0, 49, "Subsection"],
Cell[32341, 798, 238, 4, 86, "Input"],
Cell[32582, 804, 847, 16, 246, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[33466, 825, 44, 0, 49, "Subsection"],
Cell[33513, 827, 2244, 50, 65, "Text"],
Cell[35760, 879, 56, 0, 34, "Text"],
Cell[35819, 881, 683, 13, 146, "Input"],
Cell[36505, 896, 96, 2, 34, "Text"],
Cell[36604, 900, 617, 11, 146, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[37270, 917, 38, 0, 41, "Section"],
Cell[37311, 919, 3540, 76, 110, "EmphasisText"],
Cell[40854, 997, 379, 6, 106, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[41270, 1008, 28, 0, 41, "Section"],
Cell[41301, 1010, 231, 8, 37, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[41569, 1023, 23, 0, 43, "Subsubtitle"],
Cell[41595, 1025, 23, 0, 43, "Subsubtitle"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

