(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      4550,        162]*)
(*NotebookOutlinePosition[      5557,        197]*)
(*  CellTagsIndexPosition[      5483,        191]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["PVector", "ObjectName",
  CellTags->"Function?"],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  Cell[BoxData[
      RowBox[{"PVector", 
        StyleBox["[",
          "MR"], 
        StyleBox[" ",
          "MR"], 
        StyleBox[\(lab, g\),
          "MR"], 
        StyleBox["]",
          "MR"]}]]],
  "represents a vector of label lab and grade g, which can be an integer or a \
list of integers."
}], "Usage",
  CellTags->"Function?"],

Cell[" The grade defines the color and size for some cases.", "MathCaption"],

Cell[CellGroupData[{

Cell["Examples", "ExampleSection"],

Cell[BoxData[
    \(Needs["\<TCliffordAlgebra1`TClifford`\>"]\)], "Input",
  CellLabel->"In[1]:="],

Cell["\<\
A vector is represented with the PVector header. (% represents the \
immediately previous output and FullForm prints the expression as is stored \
internally by Mathematica)\
\>", "Text"],

Cell[BoxData[{
    \(PVector[v]\), "\[IndentingNewLine]", 
    \(% // FullForm\)}], "Input",
  CellLabel->"In[2]:="],

Cell["\<\
A vector with a pure grade is denoted with a second argument.\
\>", "Text"],

Cell[BoxData[{
    \(PVector[v, 1]\), "\[IndentingNewLine]", 
    \(% // FullForm\)}], "Input",
  CellLabel->"In[4]:="],

Cell["Let's declare a color flavor", "Text"],

Cell[BoxData[
    \(\(DeclareIndexFlavor[{red, Red}];\)\)], "Input",
  CellLabel->"In[6]:="],

Cell["A vector can be indexed", "Text"],

Cell[BoxData[{
    \(PVector[Subscript[v, red@i], 1]\), "\[IndentingNewLine]", 
    \(% // FullForm\)}], "Input",
  CellLabel->"In[7]:="],

Cell[BoxData[{
    \(PVector[Superscript[v, red@i], 1]\), "\[IndentingNewLine]", 
    \(% // FullForm\)}], "Input",
  CellLabel->"In[9]:="],

Cell["Another method with the same result", "Text"],

Cell[BoxData[{
    \(PVector[v\_i, 1]\), "\[IndentingNewLine]", 
    \(% // FullForm\)}], "Input",
  CellLabel->"In[11]:="],

Cell["\<\
We  denote a bivector with the second argument set to 2. The color of a \
second grade vector has changed.\
\>", "Text"],

Cell[BoxData[{
    \(PVector[A, 2]\), "\[IndentingNewLine]", 
    \(% // FullForm\)}], "Input",
  CellLabel->"In[13]:="],

Cell["\<\
If a vector has mixed grades  the second argument may be a list of the \
grades. A paravector for example can be represented as:\
\>", "Text"],

Cell[BoxData[
    \(PVector[A, {0, 1}]\)], "Input",
  CellLabel->"In[15]:="],

Cell["\<\
Of course if we are not sure we better leave the vector with unspecified \
grade.\
\>", "Text"],

Cell[BoxData[{
    \(PVector[A, 2]\), "\[IndentingNewLine]", 
    \(% // FullForm\)}], "Input",
  CellLabel->"In[16]:="],

Cell["The higher the order the larger the font used", "Text"],

Cell[BoxData[
    \(\(Table[\[IndentingNewLine]Print["\<Order \>", m, "\<:   \>", 
          PVector[u, m]]\[IndentingNewLine], {m, 0, 7}];\)\)], "Input",
  CellLabel->"In[18]:="]
}, Closed]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 800}, {0, 527}},
ScreenStyleEnvironment->"Working",
WindowToolbars->{},
WindowSize->{699, 500},
WindowMargins->{{1, Automatic}, {Automatic, -3}},
ShowSelection->True,
CommonDefaultFormatTypes->{"Output"->TraditionalForm},
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Function?"->{
    Cell[1705, 50, 54, 1, 31, "ObjectName",
      CellTags->"Function?"],
    Cell[1762, 53, 391, 15, 32, "Usage",
      CellTags->"Function?"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Function?", 5312, 182}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1705, 50, 54, 1, 31, "ObjectName",
  CellTags->"Function?"],
Cell[1762, 53, 391, 15, 32, "Usage",
  CellTags->"Function?"],
Cell[2156, 70, 76, 0, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[2257, 74, 34, 0, 40, "ExampleSection"],
Cell[2294, 76, 98, 2, 29, "Input"],
Cell[2395, 80, 197, 4, 42, "Text"],
Cell[2595, 86, 116, 3, 49, "Input"],
Cell[2714, 91, 85, 2, 25, "Text"],
Cell[2802, 95, 119, 3, 49, "Input"],
Cell[2924, 100, 44, 0, 25, "Text"],
Cell[2971, 102, 92, 2, 29, "Input"],
Cell[3066, 106, 39, 0, 25, "Text"],
Cell[3108, 108, 137, 3, 49, "Input"],
Cell[3248, 113, 139, 3, 49, "Input"],
Cell[3390, 118, 51, 0, 25, "Text"],
Cell[3444, 120, 123, 3, 49, "Input"],
Cell[3570, 125, 130, 3, 25, "Text"],
Cell[3703, 130, 120, 3, 49, "Input"],
Cell[3826, 135, 152, 3, 25, "Text"],
Cell[3981, 140, 76, 2, 29, "Input"],
Cell[4060, 144, 105, 3, 25, "Text"],
Cell[4168, 149, 120, 3, 49, "Input"],
Cell[4291, 154, 61, 0, 25, "Text"],
Cell[4355, 156, 179, 3, 69, "Input"]
}, Closed]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

