(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     67834,       1581]*)
(*NotebookOutlinePosition[     68565,       1606]*)
(*  CellTagsIndexPosition[     68521,       1602]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Rotations", "Title"],

Cell[TextData[{
  StyleBox[" Renan Cabrera\n",
    FontSize->18],
  StyleBox["Graduate student\nPhysics Dept., University of Windsor\nWindsor, \
ON, Canada N9B 3P4\nrencabla@ceibo.entelnet.bo\ncabrer7@uwindsor.ca\n\
December/2003",
    FontSize->14]
}], "Subtitle"],

Cell[BoxData[
    \(Needs["\<TCliffordAlgebra1`TClifford`\>"]\)], "Input"],

Cell[BoxData[
    \(SetCliffordBasisValueRules[\[Sigma], 3]\)], "Input"],

Cell[CellGroupData[{

Cell["Rotors", "Section"],

Cell["Operating with the exponential from the right", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(PVector[\[Sigma]\_1, 1] ** 
      Exp[PVector[\[Sigma]\_1, 1] ** 
            PVector[\[Sigma]\_2, 1] \[Theta]]\), "\[IndentingNewLine]", 
    \(\(% // CliffordExpToTrig[\[Sigma]\_1, \[Sigma]\_2]\) // 
      CliffordExpand\), "\[IndentingNewLine]", 
    \(\(% // BasisSimplify[\[Sigma]]\) // BasisSimplify[\[Sigma]]\)}], "Input"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[
          FormBox[
            RowBox[{
              FormBox[
                TagBox[
                  StyleBox[
                    InterpretationBox[\(\[Sigma]\_1\),
                      SequenceForm[ 
                        Subscript[ \[Sigma], 1]],
                      Editable->False],
                    FontColor->RGBColor[0, 0, 0.996109],
                    Magnification->1],
                  (
                  StyleForm[ #, FontColor -> RGBColor[ 
                    0, 0, .99610900000000002], Magnification -> 1.0]&)],
                "TraditionalForm"], "\[Diamond]", 
              FormBox[
                InterpretationBox[
                  SuperscriptBox["\[ExponentialE]", 
                    TagBox[
                      StyleBox[
                        RowBox[{"\[Theta]", " ", 
                          FormBox[
                            RowBox[{
                              FormBox[
                                TagBox[
                                  StyleBox[
                                    InterpretationBox[\(\[Sigma]\_1\),
                                      SequenceForm[ 
                                        Subscript[ \[Sigma], 1]],
                                      Editable->False],
                                    FontColor->RGBColor[0, 0, 0.996109],
                                    Magnification->1],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    0, 0, .99610900000000002], Magnification -> 
                                    1.0]&)],
                                "TraditionalForm"], "\[Diamond]", 
                              FormBox[
                                TagBox[
                                  StyleBox[
                                    InterpretationBox[\(\[Sigma]\_2\),
                                      SequenceForm[ 
                                        Subscript[ \[Sigma], 2]],
                                      Editable->False],
                                    FontColor->RGBColor[0, 0, 0.996109],
                                    Magnification->1],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    0, 0, .99610900000000002], Magnification -> 
                                    1.0]&)],
                                "TraditionalForm"]}],
                            "TraditionalForm"]}],
                        Magnification->1.3],
                      (StyleForm[ #, Magnification -> 1.3]&)]],
                  Superscript[ E, 
                    StyleForm[ 
                      Times[ \[Theta], 
                        NonCommutativeMultiply[ 
                          PVector[ 
                            Subscript[ \[Sigma], 1], 1], 
                          PVector[ 
                            Subscript[ \[Sigma], 2], 1]]], Magnification -> 
                      1.3]],
                  Editable->False],
                "TraditionalForm"]}],
            "TraditionalForm"],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[
          RowBox[{
            FormBox[
              RowBox[{
                FormBox[
                  TagBox[
                    StyleBox[
                      InterpretationBox[\(\[Sigma]\_1\),
                        SequenceForm[ 
                          Subscript[ \[Sigma], 1]],
                        Editable->False],
                      FontColor->RGBColor[0, 0, 0.996109],
                      Magnification->1],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      0, 0, .99610900000000002], Magnification -> 1.0]&)],
                  "TraditionalForm"], "\[Diamond]", \(cos(\[Theta])\)}],
              "TraditionalForm"], "+", 
            FormBox[
              RowBox[{
                FormBox[
                  TagBox[
                    StyleBox[
                      InterpretationBox[\(\[Sigma]\_1\),
                        SequenceForm[ 
                          Subscript[ \[Sigma], 1]],
                        Editable->False],
                      FontColor->RGBColor[0, 0, 0.996109],
                      Magnification->1],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      0, 0, .99610900000000002], Magnification -> 1.0]&)],
                  "TraditionalForm"], "\[Diamond]", 
                RowBox[{"(", 
                  RowBox[{
                    FormBox[
                      RowBox[{
                        FormBox[
                          TagBox[
                            StyleBox[
                              InterpretationBox[\(\[Sigma]\_1\),
                                SequenceForm[ 
                                  Subscript[ \[Sigma], 1]],
                                Editable->False],
                              FontColor->RGBColor[0, 0, 0.996109],
                              Magnification->1],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              0, 0, .99610900000000002], Magnification -> 
                              1.0]&)],
                          "TraditionalForm"], "\[Diamond]", 
                        FormBox[
                          TagBox[
                            StyleBox[
                              InterpretationBox[\(\[Sigma]\_2\),
                                SequenceForm[ 
                                  Subscript[ \[Sigma], 2]],
                                Editable->False],
                              FontColor->RGBColor[0, 0, 0.996109],
                              Magnification->1],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              0, 0, .99610900000000002], Magnification -> 
                              1.0]&)],
                          "TraditionalForm"]}],
                      "TraditionalForm"], " ", \(sin(\[Theta])\)}], ")"}]}],
              "TraditionalForm"]}],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[
          RowBox[{
            RowBox[{\(cos(\[Theta])\), " ", 
              FormBox[
                TagBox[
                  StyleBox[
                    InterpretationBox[\(\[Sigma]\_1\),
                      SequenceForm[ 
                        Subscript[ \[Sigma], 1]],
                      Editable->False],
                    FontColor->RGBColor[0, 0, 0.996109],
                    Magnification->1],
                  (
                  StyleForm[ #, FontColor -> RGBColor[ 
                    0, 0, .99610900000000002], Magnification -> 1.0]&)],
                "TraditionalForm"]}], "+", 
            RowBox[{
              FormBox[
                TagBox[
                  StyleBox[
                    InterpretationBox[\(\[Sigma]\_2\),
                      SequenceForm[ 
                        Subscript[ \[Sigma], 2]],
                      Editable->False],
                    FontColor->RGBColor[0, 0, 0.996109],
                    Magnification->1],
                  (
                  StyleForm[ #, FontColor -> RGBColor[ 
                    0, 0, .99610900000000002], Magnification -> 1.0]&)],
                "TraditionalForm"], " ", \(sin(\[Theta])\)}]}],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell["Now let's use the rotor method to do the same work", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Rotor\  = \ 
      Exp[\(-PVector[\[Sigma]\_1, 1] ** PVector[\[Sigma]\_2, 1]\) \[Theta]/
            2]\)], "Input"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[
          FormBox[
            InterpretationBox[
              SuperscriptBox["\[ExponentialE]", 
                TagBox[
                  StyleBox[
                    RowBox[{\(-\(1\/2\)\), " ", "\[Theta]", " ", 
                      FormBox[
                        RowBox[{
                          FormBox[
                            TagBox[
                              StyleBox[
                                InterpretationBox[\(\[Sigma]\_1\),
                                  SequenceForm[ 
                                    Subscript[ \[Sigma], 1]],
                                  Editable->False],
                                FontColor->RGBColor[0, 0, 0.996109],
                                Magnification->1],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, .99610900000000002], Magnification -> 
                                1.0]&)],
                            "TraditionalForm"], "\[Diamond]", 
                          FormBox[
                            TagBox[
                              StyleBox[
                                InterpretationBox[\(\[Sigma]\_2\),
                                  SequenceForm[ 
                                    Subscript[ \[Sigma], 2]],
                                  Editable->False],
                                FontColor->RGBColor[0, 0, 0.996109],
                                Magnification->1],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, .99610900000000002], Magnification -> 
                                1.0]&)],
                            "TraditionalForm"]}],
                        "TraditionalForm"]}],
                    Magnification->1.3],
                  (StyleForm[ #, Magnification -> 1.3]&)]],
              Superscript[ E, 
                StyleForm[ 
                  Times[ 
                    Rational[ -1, 2], \[Theta], 
                    NonCommutativeMultiply[ 
                      PVector[ 
                        Subscript[ \[Sigma], 1], 1], 
                      PVector[ 
                        Subscript[ \[Sigma], 2], 1]]], Magnification -> 1.3]],
              
              Editable->False],
            "TraditionalForm"],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Rotor ** PVector[\[Sigma]\_1, 1] ** SuperDagger[Rotor] // 
      EvaluateSuperDagger\), "\[IndentingNewLine]", 
    \(\(% // CliffordExpToTrig[\[Sigma]\_1, \[Sigma]\_2]\) // 
      CliffordExpToTrig[\[Sigma]\_2, \[Sigma]\_1]\), "\[IndentingNewLine]", 
    \(\(% // CliffordExpand\) // Expand\), "\[IndentingNewLine]", 
    \(% // BasisSimplify[\[Sigma]]\), "\[IndentingNewLine]", 
    \(% // FullSimplify\)}], "Input"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[
          FormBox[
            RowBox[{
              FormBox[
                InterpretationBox[
                  SuperscriptBox["\[ExponentialE]", 
                    TagBox[
                      StyleBox[
                        RowBox[{\(-\(1\/2\)\), " ", "\[Theta]", " ", 
                          FormBox[
                            RowBox[{
                              FormBox[
                                TagBox[
                                  StyleBox[
                                    InterpretationBox[\(\[Sigma]\_1\),
                                      SequenceForm[ 
                                        Subscript[ \[Sigma], 1]],
                                      Editable->False],
                                    FontColor->RGBColor[0, 0, 0.996109],
                                    Magnification->1],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    0, 0, .99610900000000002], Magnification -> 
                                    1.0]&)],
                                "TraditionalForm"], "\[Diamond]", 
                              FormBox[
                                TagBox[
                                  StyleBox[
                                    InterpretationBox[\(\[Sigma]\_2\),
                                      SequenceForm[ 
                                        Subscript[ \[Sigma], 2]],
                                      Editable->False],
                                    FontColor->RGBColor[0, 0, 0.996109],
                                    Magnification->1],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    0, 0, .99610900000000002], Magnification -> 
                                    1.0]&)],
                                "TraditionalForm"]}],
                            "TraditionalForm"]}],
                        Magnification->1.3],
                      (StyleForm[ #, Magnification -> 1.3]&)]],
                  Superscript[ E, 
                    StyleForm[ 
                      Times[ 
                        Rational[ -1, 2], \[Theta], 
                        NonCommutativeMultiply[ 
                          PVector[ 
                            Subscript[ \[Sigma], 1], 1], 
                          PVector[ 
                            Subscript[ \[Sigma], 2], 1]]], Magnification -> 
                      1.3]],
                  Editable->False],
                "TraditionalForm"], "\[Diamond]", 
              RowBox[{"(", 
                FormBox[
                  RowBox[{
                    FormBox[
                      TagBox[
                        StyleBox[
                          InterpretationBox[\(\[Sigma]\_1\),
                            SequenceForm[ 
                              Subscript[ \[Sigma], 1]],
                            Editable->False],
                          FontColor->RGBColor[0, 0, 0.996109],
                          Magnification->1],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0, 0, .99610900000000002], Magnification -> 1.0]&)],
                      
                      "TraditionalForm"], "\[Diamond]", 
                    FormBox[
                      InterpretationBox[
                        SuperscriptBox["\[ExponentialE]", 
                          TagBox[
                            StyleBox[
                              RowBox[{\(-\(1\/2\)\), " ", "\[Theta]", " ", 
                                FormBox[
                                  RowBox[{
                                    FormBox[
                                      TagBox[
                                        StyleBox[
                                        InterpretationBox[\(\[Sigma]\_2\),
                                        SequenceForm[ 
                                        Subscript[ \[Sigma], 2]],
                                        Editable->False],
                                        FontColor->RGBColor[0, 0, 0.996109],
                                        Magnification->1],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        0, 0, .99610900000000002], 
                                        Magnification -> 1.0]&)],
                                      "TraditionalForm"], "\[Diamond]", 
                                    FormBox[
                                      TagBox[
                                        StyleBox[
                                        InterpretationBox[\(\[Sigma]\_1\),
                                        SequenceForm[ 
                                        Subscript[ \[Sigma], 1]],
                                        Editable->False],
                                        FontColor->RGBColor[0, 0, 0.996109],
                                        Magnification->1],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        0, 0, .99610900000000002], 
                                        Magnification -> 1.0]&)],
                                      "TraditionalForm"]}],
                                  "TraditionalForm"]}],
                              Magnification->1.3],
                            (StyleForm[ #, Magnification -> 1.3]&)]],
                        Superscript[ E, 
                          StyleForm[ 
                            Times[ 
                              Rational[ -1, 2], \[Theta], 
                              NonCommutativeMultiply[ 
                                PVector[ 
                                  Subscript[ \[Sigma], 2], 1], 
                                PVector[ 
                                  Subscript[ \[Sigma], 1], 1]]], 
                            Magnification -> 1.3]],
                        Editable->False],
                      "TraditionalForm"]}],
                  "TraditionalForm"], ")"}]}],
            "TraditionalForm"],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[
          FormBox[
            RowBox[{
              RowBox[{"(", 
                RowBox[{\(cos(\[Theta]\/2)\), "-", 
                  RowBox[{
                    FormBox[
                      RowBox[{
                        FormBox[
                          TagBox[
                            StyleBox[
                              InterpretationBox[\(\[Sigma]\_1\),
                                SequenceForm[ 
                                  Subscript[ \[Sigma], 1]],
                                Editable->False],
                              FontColor->RGBColor[0, 0, 0.996109],
                              Magnification->1],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              0, 0, .99610900000000002], Magnification -> 
                              1.0]&)],
                          "TraditionalForm"], "\[Diamond]", 
                        FormBox[
                          TagBox[
                            StyleBox[
                              InterpretationBox[\(\[Sigma]\_2\),
                                SequenceForm[ 
                                  Subscript[ \[Sigma], 2]],
                                Editable->False],
                              FontColor->RGBColor[0, 0, 0.996109],
                              Magnification->1],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              0, 0, .99610900000000002], Magnification -> 
                              1.0]&)],
                          "TraditionalForm"]}],
                      "TraditionalForm"], " ", \(sin(\[Theta]\/2)\)}]}], 
                ")"}], "\[Diamond]", 
              RowBox[{"(", 
                FormBox[
                  RowBox[{
                    FormBox[
                      TagBox[
                        StyleBox[
                          InterpretationBox[\(\[Sigma]\_1\),
                            SequenceForm[ 
                              Subscript[ \[Sigma], 1]],
                            Editable->False],
                          FontColor->RGBColor[0, 0, 0.996109],
                          Magnification->1],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0, 0, .99610900000000002], Magnification -> 1.0]&)],
                      
                      "TraditionalForm"], "\[Diamond]", 
                    RowBox[{"(", 
                      RowBox[{\(cos(\[Theta]\/2)\), "-", 
                        RowBox[{
                          FormBox[
                            RowBox[{
                              FormBox[
                                TagBox[
                                  StyleBox[
                                    InterpretationBox[\(\[Sigma]\_2\),
                                      SequenceForm[ 
                                        Subscript[ \[Sigma], 2]],
                                      Editable->False],
                                    FontColor->RGBColor[0, 0, 0.996109],
                                    Magnification->1],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    0, 0, .99610900000000002], Magnification -> 
                                    1.0]&)],
                                "TraditionalForm"], "\[Diamond]", 
                              FormBox[
                                TagBox[
                                  StyleBox[
                                    InterpretationBox[\(\[Sigma]\_1\),
                                      SequenceForm[ 
                                        Subscript[ \[Sigma], 1]],
                                      Editable->False],
                                    FontColor->RGBColor[0, 0, 0.996109],
                                    Magnification->1],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    0, 0, .99610900000000002], Magnification -> 
                                    1.0]&)],
                                "TraditionalForm"]}],
                            "TraditionalForm"], " ", \(sin(\[Theta]\/2)\)}]}],
                       ")"}]}],
                  "TraditionalForm"], ")"}]}],
            "TraditionalForm"],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[
          RowBox[{
            FormBox[
              RowBox[{\(cos(\[Theta]\/2)\), "\[Diamond]", 
                RowBox[{"(", 
                  FormBox[
                    RowBox[{
                      FormBox[
                        TagBox[
                          StyleBox[
                            InterpretationBox[\(\[Sigma]\_1\),
                              SequenceForm[ 
                                Subscript[ \[Sigma], 1]],
                              Editable->False],
                            FontColor->RGBColor[0, 0, 0.996109],
                            Magnification->1],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0, 0, .99610900000000002], Magnification -> 
                            1.0]&)],
                        "TraditionalForm"], 
                      "\[Diamond]", \(cos(\[Theta]\/2)\)}],
                    "TraditionalForm"], ")"}]}],
              "TraditionalForm"], "+", 
            FormBox[
              RowBox[{\(cos(\[Theta]\/2)\), "\[Diamond]", 
                RowBox[{"(", 
                  FormBox[
                    RowBox[{
                      FormBox[
                        TagBox[
                          StyleBox[
                            InterpretationBox[\(\[Sigma]\_1\),
                              SequenceForm[ 
                                Subscript[ \[Sigma], 1]],
                              Editable->False],
                            FontColor->RGBColor[0, 0, 0.996109],
                            Magnification->1],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0, 0, .99610900000000002], Magnification -> 
                            1.0]&)],
                        "TraditionalForm"], "\[Diamond]", 
                      RowBox[{"(", 
                        RowBox[{
                          RowBox[{"-", 
                            RowBox[{"(", 
                              FormBox[
                                RowBox[{
                                  FormBox[
                                    TagBox[
                                      StyleBox[
                                        InterpretationBox[\(\[Sigma]\_2\),
                                        SequenceForm[ 
                                        Subscript[ \[Sigma], 2]],
                                        Editable->False],
                                        FontColor->RGBColor[0, 0, 0.996109],
                                        Magnification->1],
                                      (
                                      StyleForm[ #, FontColor -> RGBColor[ 
                                        0, 0, .99610900000000002], 
                                        Magnification -> 1.0]&)],
                                    "TraditionalForm"], "\[Diamond]", 
                                  FormBox[
                                    TagBox[
                                      StyleBox[
                                        InterpretationBox[\(\[Sigma]\_1\),
                                        SequenceForm[ 
                                        Subscript[ \[Sigma], 1]],
                                        Editable->False],
                                        FontColor->RGBColor[0, 0, 0.996109],
                                        Magnification->1],
                                      (
                                      StyleForm[ #, FontColor -> RGBColor[ 
                                        0, 0, .99610900000000002], 
                                        Magnification -> 1.0]&)],
                                    "TraditionalForm"]}],
                                "TraditionalForm"], ")"}]}], 
                          " ", \(sin(\[Theta]\/2)\)}], ")"}]}],
                    "TraditionalForm"], ")"}]}],
              "TraditionalForm"], "+", 
            FormBox[
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"-", 
                      RowBox[{"(", 
                        FormBox[
                          RowBox[{
                            FormBox[
                              TagBox[
                                StyleBox[
                                  InterpretationBox[\(\[Sigma]\_1\),
                                    SequenceForm[ 
                                      Subscript[ \[Sigma], 1]],
                                    Editable->False],
                                  FontColor->RGBColor[0, 0, 0.996109],
                                  Magnification->1],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  0, 0, .99610900000000002], Magnification -> 
                                  1.0]&)],
                              "TraditionalForm"], "\[Diamond]", 
                            FormBox[
                              TagBox[
                                StyleBox[
                                  InterpretationBox[\(\[Sigma]\_2\),
                                    SequenceForm[ 
                                      Subscript[ \[Sigma], 2]],
                                    Editable->False],
                                  FontColor->RGBColor[0, 0, 0.996109],
                                  Magnification->1],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  0, 0, .99610900000000002], Magnification -> 
                                  1.0]&)],
                              "TraditionalForm"]}],
                          "TraditionalForm"], ")"}]}], 
                    " ", \(sin(\[Theta]\/2)\)}], ")"}], "\[Diamond]", 
                RowBox[{"(", 
                  FormBox[
                    RowBox[{
                      FormBox[
                        TagBox[
                          StyleBox[
                            InterpretationBox[\(\[Sigma]\_1\),
                              SequenceForm[ 
                                Subscript[ \[Sigma], 1]],
                              Editable->False],
                            FontColor->RGBColor[0, 0, 0.996109],
                            Magnification->1],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0, 0, .99610900000000002], Magnification -> 
                            1.0]&)],
                        "TraditionalForm"], 
                      "\[Diamond]", \(cos(\[Theta]\/2)\)}],
                    "TraditionalForm"], ")"}]}],
              "TraditionalForm"], "+", 
            FormBox[
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"-", 
                      RowBox[{"(", 
                        FormBox[
                          RowBox[{
                            FormBox[
                              TagBox[
                                StyleBox[
                                  InterpretationBox[\(\[Sigma]\_1\),
                                    SequenceForm[ 
                                      Subscript[ \[Sigma], 1]],
                                    Editable->False],
                                  FontColor->RGBColor[0, 0, 0.996109],
                                  Magnification->1],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  0, 0, .99610900000000002], Magnification -> 
                                  1.0]&)],
                              "TraditionalForm"], "\[Diamond]", 
                            FormBox[
                              TagBox[
                                StyleBox[
                                  InterpretationBox[\(\[Sigma]\_2\),
                                    SequenceForm[ 
                                      Subscript[ \[Sigma], 2]],
                                    Editable->False],
                                  FontColor->RGBColor[0, 0, 0.996109],
                                  Magnification->1],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  0, 0, .99610900000000002], Magnification -> 
                                  1.0]&)],
                              "TraditionalForm"]}],
                          "TraditionalForm"], ")"}]}], 
                    " ", \(sin(\[Theta]\/2)\)}], ")"}], "\[Diamond]", 
                RowBox[{"(", 
                  FormBox[
                    RowBox[{
                      FormBox[
                        TagBox[
                          StyleBox[
                            InterpretationBox[\(\[Sigma]\_1\),
                              SequenceForm[ 
                                Subscript[ \[Sigma], 1]],
                              Editable->False],
                            FontColor->RGBColor[0, 0, 0.996109],
                            Magnification->1],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0, 0, .99610900000000002], Magnification -> 
                            1.0]&)],
                        "TraditionalForm"], "\[Diamond]", 
                      RowBox[{"(", 
                        RowBox[{
                          RowBox[{"-", 
                            RowBox[{"(", 
                              FormBox[
                                RowBox[{
                                  FormBox[
                                    TagBox[
                                      StyleBox[
                                        InterpretationBox[\(\[Sigma]\_2\),
                                        SequenceForm[ 
                                        Subscript[ \[Sigma], 2]],
                                        Editable->False],
                                        FontColor->RGBColor[0, 0, 0.996109],
                                        Magnification->1],
                                      (
                                      StyleForm[ #, FontColor -> RGBColor[ 
                                        0, 0, .99610900000000002], 
                                        Magnification -> 1.0]&)],
                                    "TraditionalForm"], "\[Diamond]", 
                                  FormBox[
                                    TagBox[
                                      StyleBox[
                                        InterpretationBox[\(\[Sigma]\_1\),
                                        SequenceForm[ 
                                        Subscript[ \[Sigma], 1]],
                                        Editable->False],
                                        FontColor->RGBColor[0, 0, 0.996109],
                                        Magnification->1],
                                      (
                                      StyleForm[ #, FontColor -> RGBColor[ 
                                        0, 0, .99610900000000002], 
                                        Magnification -> 1.0]&)],
                                    "TraditionalForm"]}],
                                "TraditionalForm"], ")"}]}], 
                          " ", \(sin(\[Theta]\/2)\)}], ")"}]}],
                    "TraditionalForm"], ")"}]}],
              "TraditionalForm"]}],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[
          RowBox[{
            RowBox[{
              FormBox[
                TagBox[
                  StyleBox[
                    InterpretationBox[\(\[Sigma]\_1\),
                      SequenceForm[ 
                        Subscript[ \[Sigma], 1]],
                      Editable->False],
                    FontColor->RGBColor[0, 0, 0.996109],
                    Magnification->1],
                  (
                  StyleForm[ #, FontColor -> RGBColor[ 
                    0, 0, .99610900000000002], Magnification -> 1.0]&)],
                "TraditionalForm"], " ", \(\(cos\^2\)(\[Theta]\/2)\)}], "+", 
            RowBox[{"2", " ", 
              FormBox[
                TagBox[
                  StyleBox[
                    InterpretationBox[\(\[Sigma]\_2\),
                      SequenceForm[ 
                        Subscript[ \[Sigma], 2]],
                      Editable->False],
                    FontColor->RGBColor[0, 0, 0.996109],
                    Magnification->1],
                  (
                  StyleForm[ #, FontColor -> RGBColor[ 
                    0, 0, .99610900000000002], Magnification -> 1.0]&)],
                "TraditionalForm"], " ", \(sin(\[Theta]\/2)\), 
              " ", \(cos(\[Theta]\/2)\)}], "-", 
            RowBox[{
              FormBox[
                TagBox[
                  StyleBox[
                    InterpretationBox[\(\[Sigma]\_1\),
                      SequenceForm[ 
                        Subscript[ \[Sigma], 1]],
                      Editable->False],
                    FontColor->RGBColor[0, 0, 0.996109],
                    Magnification->1],
                  (
                  StyleForm[ #, FontColor -> RGBColor[ 
                    0, 0, .99610900000000002], Magnification -> 1.0]&)],
                "TraditionalForm"], " ", \(\(sin\^2\)(\[Theta]\/2)\)}]}],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[
          RowBox[{
            RowBox[{\(cos(\[Theta])\), " ", 
              FormBox[
                TagBox[
                  StyleBox[
                    InterpretationBox[\(\[Sigma]\_1\),
                      SequenceForm[ 
                        Subscript[ \[Sigma], 1]],
                      Editable->False],
                    FontColor->RGBColor[0, 0, 0.996109],
                    Magnification->1],
                  (
                  StyleForm[ #, FontColor -> RGBColor[ 
                    0, 0, .99610900000000002], Magnification -> 1.0]&)],
                "TraditionalForm"]}], "+", 
            RowBox[{
              FormBox[
                TagBox[
                  StyleBox[
                    InterpretationBox[\(\[Sigma]\_2\),
                      SequenceForm[ 
                        Subscript[ \[Sigma], 2]],
                      Editable->False],
                    FontColor->RGBColor[0, 0, 0.996109],
                    Magnification->1],
                  (
                  StyleForm[ #, FontColor -> RGBColor[ 
                    0, 0, .99610900000000002], Magnification -> 1.0]&)],
                "TraditionalForm"], " ", \(sin(\[Theta])\)}]}],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Composition of Rotations", "Section"],

Cell["\<\
What is the result of a 90 degrees rotation in the 1-2 plane followed by a 90 \
degrees rotation in the 2-3 plane?\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Rotor12\  = \ 
      Exp[PVector[\[Sigma]\_2, 1] ** PVector[\[Sigma]\_1, 1] \[Theta]/
              2] /. \[Theta] \[Rule] Pi/2\)], "Input"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[
          FormBox[
            InterpretationBox[
              SuperscriptBox["\[ExponentialE]", 
                TagBox[
                  StyleBox[
                    RowBox[{\(1\/4\), " ", "\[Pi]", " ", 
                      FormBox[
                        RowBox[{
                          FormBox[
                            TagBox[
                              StyleBox[
                                InterpretationBox[\(\[Sigma]\_2\),
                                  SequenceForm[ 
                                    Subscript[ \[Sigma], 2]],
                                  Editable->False],
                                FontColor->RGBColor[0, 0, 0.996109],
                                Magnification->1],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, .99610900000000002], Magnification -> 
                                1.0]&)],
                            "TraditionalForm"], "\[Diamond]", 
                          FormBox[
                            TagBox[
                              StyleBox[
                                InterpretationBox[\(\[Sigma]\_1\),
                                  SequenceForm[ 
                                    Subscript[ \[Sigma], 1]],
                                  Editable->False],
                                FontColor->RGBColor[0, 0, 0.996109],
                                Magnification->1],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, .99610900000000002], Magnification -> 
                                1.0]&)],
                            "TraditionalForm"]}],
                        "TraditionalForm"]}],
                    Magnification->1.3],
                  (StyleForm[ #, Magnification -> 1.3]&)]],
              Superscript[ E, 
                StyleForm[ 
                  Times[ 
                    Rational[ 1, 4], Pi, 
                    NonCommutativeMultiply[ 
                      PVector[ 
                        Subscript[ \[Sigma], 2], 1], 
                      PVector[ 
                        Subscript[ \[Sigma], 1], 1]]], Magnification -> 1.3]],
              
              Editable->False],
            "TraditionalForm"],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Rotor23\  = \ 
      Exp[PVector[\[Sigma]\_3, 1] ** PVector[\[Sigma]\_2, 1] \[Theta]/
              2] /. \[Theta] \[Rule] Pi/2\)], "Input"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[
          FormBox[
            InterpretationBox[
              SuperscriptBox["\[ExponentialE]", 
                TagBox[
                  StyleBox[
                    RowBox[{\(1\/4\), " ", "\[Pi]", " ", 
                      FormBox[
                        RowBox[{
                          FormBox[
                            TagBox[
                              StyleBox[
                                InterpretationBox[\(\[Sigma]\_3\),
                                  SequenceForm[ 
                                    Subscript[ \[Sigma], 3]],
                                  Editable->False],
                                FontColor->RGBColor[0, 0, 0.996109],
                                Magnification->1],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, .99610900000000002], Magnification -> 
                                1.0]&)],
                            "TraditionalForm"], "\[Diamond]", 
                          FormBox[
                            TagBox[
                              StyleBox[
                                InterpretationBox[\(\[Sigma]\_2\),
                                  SequenceForm[ 
                                    Subscript[ \[Sigma], 2]],
                                  Editable->False],
                                FontColor->RGBColor[0, 0, 0.996109],
                                Magnification->1],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, .99610900000000002], Magnification -> 
                                1.0]&)],
                            "TraditionalForm"]}],
                        "TraditionalForm"]}],
                    Magnification->1.3],
                  (StyleForm[ #, Magnification -> 1.3]&)]],
              Superscript[ E, 
                StyleForm[ 
                  Times[ 
                    Rational[ 1, 4], Pi, 
                    NonCommutativeMultiply[ 
                      PVector[ 
                        Subscript[ \[Sigma], 3], 1], 
                      PVector[ 
                        Subscript[ \[Sigma], 2], 1]]], Magnification -> 1.3]],
              
              Editable->False],
            "TraditionalForm"],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell["The rotor of the composition is", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Rotor23 ** Rotor12\)], "Input"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[
          FormBox[
            RowBox[{
              FormBox[
                InterpretationBox[
                  SuperscriptBox["\[ExponentialE]", 
                    TagBox[
                      StyleBox[
                        RowBox[{\(1\/4\), " ", "\[Pi]", " ", 
                          FormBox[
                            RowBox[{
                              FormBox[
                                TagBox[
                                  StyleBox[
                                    InterpretationBox[\(\[Sigma]\_3\),
                                      SequenceForm[ 
                                        Subscript[ \[Sigma], 3]],
                                      Editable->False],
                                    FontColor->RGBColor[0, 0, 0.996109],
                                    Magnification->1],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    0, 0, .99610900000000002], Magnification -> 
                                    1.0]&)],
                                "TraditionalForm"], "\[Diamond]", 
                              FormBox[
                                TagBox[
                                  StyleBox[
                                    InterpretationBox[\(\[Sigma]\_2\),
                                      SequenceForm[ 
                                        Subscript[ \[Sigma], 2]],
                                      Editable->False],
                                    FontColor->RGBColor[0, 0, 0.996109],
                                    Magnification->1],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    0, 0, .99610900000000002], Magnification -> 
                                    1.0]&)],
                                "TraditionalForm"]}],
                            "TraditionalForm"]}],
                        Magnification->1.3],
                      (StyleForm[ #, Magnification -> 1.3]&)]],
                  Superscript[ E, 
                    StyleForm[ 
                      Times[ 
                        Rational[ 1, 4], Pi, 
                        NonCommutativeMultiply[ 
                          PVector[ 
                            Subscript[ \[Sigma], 3], 1], 
                          PVector[ 
                            Subscript[ \[Sigma], 2], 1]]], Magnification -> 
                      1.3]],
                  Editable->False],
                "TraditionalForm"], "\[Diamond]", 
              FormBox[
                InterpretationBox[
                  SuperscriptBox["\[ExponentialE]", 
                    TagBox[
                      StyleBox[
                        RowBox[{\(1\/4\), " ", "\[Pi]", " ", 
                          FormBox[
                            RowBox[{
                              FormBox[
                                TagBox[
                                  StyleBox[
                                    InterpretationBox[\(\[Sigma]\_2\),
                                      SequenceForm[ 
                                        Subscript[ \[Sigma], 2]],
                                      Editable->False],
                                    FontColor->RGBColor[0, 0, 0.996109],
                                    Magnification->1],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    0, 0, .99610900000000002], Magnification -> 
                                    1.0]&)],
                                "TraditionalForm"], "\[Diamond]", 
                              FormBox[
                                TagBox[
                                  StyleBox[
                                    InterpretationBox[\(\[Sigma]\_1\),
                                      SequenceForm[ 
                                        Subscript[ \[Sigma], 1]],
                                      Editable->False],
                                    FontColor->RGBColor[0, 0, 0.996109],
                                    Magnification->1],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    0, 0, .99610900000000002], Magnification -> 
                                    1.0]&)],
                                "TraditionalForm"]}],
                            "TraditionalForm"]}],
                        Magnification->1.3],
                      (StyleForm[ #, Magnification -> 1.3]&)]],
                  Superscript[ E, 
                    StyleForm[ 
                      Times[ 
                        Rational[ 1, 4], Pi, 
                        NonCommutativeMultiply[ 
                          PVector[ 
                            Subscript[ \[Sigma], 2], 1], 
                          PVector[ 
                            Subscript[ \[Sigma], 1], 1]]], Magnification -> 
                      1.3]],
                  Editable->False],
                "TraditionalForm"]}],
            "TraditionalForm"],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell["Expanding this rotor we find", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(Rotor23 ** Rotor12 // CliffordExpToTrig[\[Sigma]\_3, \[Sigma]\_2]\) // 
      CliffordExpToTrig[\[Sigma]\_2, \[Sigma]\_1]\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(CliffordExpand[%%]\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(CompRotor = \(BasisSimplify[\[Sigma]]\)[%%] // Expand\)}], "Input"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[
          FormBox[
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  FractionBox[
                    FormBox[
                      RowBox[{
                        FormBox[
                          TagBox[
                            StyleBox[
                              InterpretationBox[\(\[Sigma]\_3\),
                                SequenceForm[ 
                                  Subscript[ \[Sigma], 3]],
                                Editable->False],
                              FontColor->RGBColor[0, 0, 0.996109],
                              Magnification->1],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              0, 0, .99610900000000002], Magnification -> 
                              1.0]&)],
                          "TraditionalForm"], "\[Diamond]", 
                        FormBox[
                          TagBox[
                            StyleBox[
                              InterpretationBox[\(\[Sigma]\_2\),
                                SequenceForm[ 
                                  Subscript[ \[Sigma], 2]],
                                Editable->False],
                              FontColor->RGBColor[0, 0, 0.996109],
                              Magnification->1],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              0, 0, .99610900000000002], Magnification -> 
                              1.0]&)],
                          "TraditionalForm"]}],
                      "TraditionalForm"], \(\@2\)], "+", \(1\/\@2\)}], ")"}], 
              "\[Diamond]", 
              RowBox[{"(", 
                RowBox[{
                  FractionBox[
                    FormBox[
                      RowBox[{
                        FormBox[
                          TagBox[
                            StyleBox[
                              InterpretationBox[\(\[Sigma]\_2\),
                                SequenceForm[ 
                                  Subscript[ \[Sigma], 2]],
                                Editable->False],
                              FontColor->RGBColor[0, 0, 0.996109],
                              Magnification->1],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              0, 0, .99610900000000002], Magnification -> 
                              1.0]&)],
                          "TraditionalForm"], "\[Diamond]", 
                        FormBox[
                          TagBox[
                            StyleBox[
                              InterpretationBox[\(\[Sigma]\_1\),
                                SequenceForm[ 
                                  Subscript[ \[Sigma], 1]],
                                Editable->False],
                              FontColor->RGBColor[0, 0, 0.996109],
                              Magnification->1],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              0, 0, .99610900000000002], Magnification -> 
                              1.0]&)],
                          "TraditionalForm"]}],
                      "TraditionalForm"], \(\@2\)], "+", \(1\/\@2\)}], 
                ")"}]}],
            "TraditionalForm"],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"],

Cell[BoxData[
    \(TraditionalForm\`\*"\<\"\"\>"\)], "Print"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[
          RowBox[{
            FormBox[\(1\/\@2\[Diamond]1\/\@2\),
              "TraditionalForm"], "+", 
            FormBox[
              RowBox[{\(1\/\@2\), "\[Diamond]", 
                FractionBox[
                  FormBox[
                    RowBox[{
                      FormBox[
                        TagBox[
                          StyleBox[
                            InterpretationBox[\(\[Sigma]\_2\),
                              SequenceForm[ 
                                Subscript[ \[Sigma], 2]],
                              Editable->False],
                            FontColor->RGBColor[0, 0, 0.996109],
                            Magnification->1],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0, 0, .99610900000000002], Magnification -> 
                            1.0]&)],
                        "TraditionalForm"], "\[Diamond]", 
                      FormBox[
                        TagBox[
                          StyleBox[
                            InterpretationBox[\(\[Sigma]\_1\),
                              SequenceForm[ 
                                Subscript[ \[Sigma], 1]],
                              Editable->False],
                            FontColor->RGBColor[0, 0, 0.996109],
                            Magnification->1],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0, 0, .99610900000000002], Magnification -> 
                            1.0]&)],
                        "TraditionalForm"]}],
                    "TraditionalForm"], \(\@2\)]}],
              "TraditionalForm"], "+", 
            FormBox[
              RowBox[{
                FractionBox[
                  FormBox[
                    RowBox[{
                      FormBox[
                        TagBox[
                          StyleBox[
                            InterpretationBox[\(\[Sigma]\_3\),
                              SequenceForm[ 
                                Subscript[ \[Sigma], 3]],
                              Editable->False],
                            FontColor->RGBColor[0, 0, 0.996109],
                            Magnification->1],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0, 0, .99610900000000002], Magnification -> 
                            1.0]&)],
                        "TraditionalForm"], "\[Diamond]", 
                      FormBox[
                        TagBox[
                          StyleBox[
                            InterpretationBox[\(\[Sigma]\_2\),
                              SequenceForm[ 
                                Subscript[ \[Sigma], 2]],
                              Editable->False],
                            FontColor->RGBColor[0, 0, 0.996109],
                            Magnification->1],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0, 0, .99610900000000002], Magnification -> 
                            1.0]&)],
                        "TraditionalForm"]}],
                    "TraditionalForm"], \(\@2\)], "\[Diamond]", \(1\/\@2\)}],
              "TraditionalForm"], "+", 
            FormBox[
              RowBox[{
                FractionBox[
                  FormBox[
                    RowBox[{
                      FormBox[
                        TagBox[
                          StyleBox[
                            InterpretationBox[\(\[Sigma]\_3\),
                              SequenceForm[ 
                                Subscript[ \[Sigma], 3]],
                              Editable->False],
                            FontColor->RGBColor[0, 0, 0.996109],
                            Magnification->1],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0, 0, .99610900000000002], Magnification -> 
                            1.0]&)],
                        "TraditionalForm"], "\[Diamond]", 
                      FormBox[
                        TagBox[
                          StyleBox[
                            InterpretationBox[\(\[Sigma]\_2\),
                              SequenceForm[ 
                                Subscript[ \[Sigma], 2]],
                              Editable->False],
                            FontColor->RGBColor[0, 0, 0.996109],
                            Magnification->1],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0, 0, .99610900000000002], Magnification -> 
                            1.0]&)],
                        "TraditionalForm"]}],
                    "TraditionalForm"], \(\@2\)], "\[Diamond]", 
                FractionBox[
                  FormBox[
                    RowBox[{
                      FormBox[
                        TagBox[
                          StyleBox[
                            InterpretationBox[\(\[Sigma]\_2\),
                              SequenceForm[ 
                                Subscript[ \[Sigma], 2]],
                              Editable->False],
                            FontColor->RGBColor[0, 0, 0.996109],
                            Magnification->1],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0, 0, .99610900000000002], Magnification -> 
                            1.0]&)],
                        "TraditionalForm"], "\[Diamond]", 
                      FormBox[
                        TagBox[
                          StyleBox[
                            InterpretationBox[\(\[Sigma]\_1\),
                              SequenceForm[ 
                                Subscript[ \[Sigma], 1]],
                              Editable->False],
                            FontColor->RGBColor[0, 0, 0.996109],
                            Magnification->1],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0, 0, .99610900000000002], Magnification -> 
                            1.0]&)],
                        "TraditionalForm"]}],
                    "TraditionalForm"], \(\@2\)]}],
              "TraditionalForm"]}],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"],

Cell[BoxData[
    \(TraditionalForm\`\*"\<\"\"\>"\)], "Print"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[
          RowBox[{
            RowBox[{\(-\(1\/2\)\), " ", 
              FormBox[
                RowBox[{
                  FormBox[
                    TagBox[
                      StyleBox[
                        InterpretationBox[\(\[Sigma]\_1\),
                          SequenceForm[ 
                            Subscript[ \[Sigma], 1]],
                          Editable->False],
                        FontColor->RGBColor[0, 0, 0.996109],
                        Magnification->1],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, .99610900000000002], Magnification -> 1.0]&)],
                    "TraditionalForm"], "\[Diamond]", 
                  FormBox[
                    TagBox[
                      StyleBox[
                        InterpretationBox[\(\[Sigma]\_2\),
                          SequenceForm[ 
                            Subscript[ \[Sigma], 2]],
                          Editable->False],
                        FontColor->RGBColor[0, 0, 0.996109],
                        Magnification->1],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, .99610900000000002], Magnification -> 1.0]&)],
                    "TraditionalForm"]}],
                "TraditionalForm"]}], "-", 
            FractionBox[
              FormBox[
                RowBox[{
                  FormBox[
                    TagBox[
                      StyleBox[
                        InterpretationBox[\(\[Sigma]\_1\),
                          SequenceForm[ 
                            Subscript[ \[Sigma], 1]],
                          Editable->False],
                        FontColor->RGBColor[0, 0, 0.996109],
                        Magnification->1],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, .99610900000000002], Magnification -> 1.0]&)],
                    "TraditionalForm"], "\[Diamond]", 
                  FormBox[
                    TagBox[
                      StyleBox[
                        InterpretationBox[\(\[Sigma]\_3\),
                          SequenceForm[ 
                            Subscript[ \[Sigma], 3]],
                          Editable->False],
                        FontColor->RGBColor[0, 0, 0.996109],
                        Magnification->1],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, .99610900000000002], Magnification -> 1.0]&)],
                    "TraditionalForm"]}],
                "TraditionalForm"], "2"], "-", 
            FractionBox[
              FormBox[
                RowBox[{
                  FormBox[
                    TagBox[
                      StyleBox[
                        InterpretationBox[\(\[Sigma]\_2\),
                          SequenceForm[ 
                            Subscript[ \[Sigma], 2]],
                          Editable->False],
                        FontColor->RGBColor[0, 0, 0.996109],
                        Magnification->1],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, .99610900000000002], Magnification -> 1.0]&)],
                    "TraditionalForm"], "\[Diamond]", 
                  FormBox[
                    TagBox[
                      StyleBox[
                        InterpretationBox[\(\[Sigma]\_3\),
                          SequenceForm[ 
                            Subscript[ \[Sigma], 3]],
                          Editable->False],
                        FontColor->RGBColor[0, 0, 0.996109],
                        Magnification->1],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, .99610900000000002], Magnification -> 1.0]&)],
                    "TraditionalForm"]}],
                "TraditionalForm"], "2"], "+", \(1\/2\)}],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\
Now lets take the real and imaginary part. The real part gives us the Cos of \
the half angle and the imaginary part gives us the plane of rotation.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(RealPart[CompRotor] // ExpandRealPart\) // 
      BasisSimplify[\[Sigma]]\), "\[IndentingNewLine]", 
    \(Print["\<The angle of rotation is\>"]\), "\[IndentingNewLine]", 
    \(2*ArcCos[%%]\)}], "Input"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[\(1\/2\),
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"],

Cell[BoxData[
    \(TraditionalForm\`"The angle of rotation is"\)], "Print"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[\(\(2\ \[Pi]\)\/3\),
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["", "Subsubtitle"],

Cell["", "Subsubtitle"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 800}, {0, 527}},
AutoGeneratedPackage->None,
WindowToolbars->{},
WindowSize->{744, 500},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
StyleDefinitions -> "TensorialStyle.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 26, 0, 76, "Title"],
Cell[1756, 54, 265, 7, 147, "Subtitle"],
Cell[2024, 63, 74, 1, 46, "Input"],
Cell[2101, 66, 72, 1, 46, "Input"],

Cell[CellGroupData[{
Cell[2198, 71, 25, 0, 61, "Section"],
Cell[2226, 73, 61, 0, 34, "Text"],

Cell[CellGroupData[{
Cell[2312, 77, 350, 6, 86, "Input"],
Cell[2665, 85, 3346, 73, 70, "Output"],
Cell[6014, 160, 3190, 73, 70, "Output"],
Cell[9207, 235, 1417, 36, 70, "Output"]
}, Open  ]],
Cell[10639, 274, 66, 0, 34, "Text"],

Cell[CellGroupData[{
Cell[10730, 278, 136, 3, 46, "Input"],
Cell[10869, 283, 2574, 58, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[13480, 346, 439, 7, 126, "Input"],
Cell[13922, 355, 6472, 130, 70, "Output"],
Cell[20397, 487, 4658, 98, 70, "Output"],
Cell[25058, 587, 11789, 238, 70, "Output"],
Cell[36850, 827, 2083, 51, 70, "Output"],
Cell[38936, 880, 1417, 36, 70, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[40402, 922, 43, 0, 41, "Section"],
Cell[40448, 924, 138, 3, 34, "Text"],

Cell[CellGroupData[{
Cell[40611, 931, 160, 3, 46, "Input"],
Cell[40774, 936, 2559, 58, 40, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[43370, 999, 160, 3, 46, "Input"],
Cell[43533, 1004, 2559, 58, 40, "Output"]
}, Open  ]],
Cell[46107, 1065, 47, 0, 34, "Text"],

Cell[CellGroupData[{
Cell[46179, 1069, 51, 1, 46, "Input"],
Cell[46233, 1072, 5403, 112, 40, "Output"]
}, Open  ]],
Cell[51651, 1187, 44, 0, 34, "Text"],

Cell[CellGroupData[{
Cell[51720, 1191, 401, 6, 126, "Input"],
Cell[52124, 1199, 3615, 80, 58, "Output"],
Cell[55742, 1281, 62, 1, 25, "Print"],
Cell[55807, 1284, 6624, 147, 54, "Output"],
Cell[62434, 1433, 62, 1, 25, "Print"],
Cell[62499, 1436, 4216, 98, 47, "Output"]
}, Open  ]],
Cell[66730, 1537, 172, 3, 54, "Text"],

Cell[CellGroupData[{
Cell[66927, 1544, 227, 4, 86, "Input"],
Cell[67157, 1550, 229, 7, 47, "Output"],
Cell[67389, 1559, 76, 1, 25, "Print"],
Cell[67468, 1562, 240, 7, 47, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[67757, 1575, 23, 0, 42, "Subsubtitle"],
Cell[67783, 1577, 23, 0, 43, "Subsubtitle"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

