(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      9653,        298]*)
(*NotebookOutlinePosition[     10660,        333]*)
(*  CellTagsIndexPosition[     10585,        327]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["SetCliffordBasisValueRules", "ObjectName",
  CellTags->"Function?"],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  Cell[BoxData[
      \(SetCliffordBasisValueRules[e]\)]],
  "defines an orthonormal basis with label e."
}], "Usage",
  CellTags->"Function?"],

Cell[" The label is stored in the list BasisLabelsList.", "MathCaption"],

Cell["\<\
 CliffordBasis[e,n] generates the complete list of unitary mutivectors of  \
the space of grade n.\
\>", "MathCaption"],

Cell["\<\
 CliffordBasis[e,{n,m}] generates the list of unitary mutivectors of grade m \
in the space of grade n.\
\>", "MathCaption"],

Cell[TextData[{
  "See also: ",
  ButtonBox["BasisInnerToGeometricP",
    ButtonData:>{"BasisInnerToGeometricP", None},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["SetParavectorBasisValues",
    ButtonData:>{"SetParavectorBasisValues", None},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["BasisWedgeToGeometricP",
    ButtonData:>{"BasisWedgeToGeometricP", None},
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["BasisSimplify",
    ButtonData:>{"BasisSimplify", None},
    ButtonStyle->"AddOnsLink"],
  "."
}], "MathCaption"],

Cell[CellGroupData[{

Cell["Examples", "ExampleSection"],

Cell[BoxData[
    \(Needs["\<TCliffordAlgebra1`TClifford`\>"]\)], "Input",
  CellLabel->"In[1]:="],

Cell["\<\
Any vector can be expressed as a linear combination of the basis vectors.\
\>", "Text"],

Cell[BoxData[{
    \(\(DeclareBaseIndices[{1, 2, 3}];\)\), "\[IndentingNewLine]", 
    \(DefineTensorShortcuts[{{a, b}, 1}]\)}], "Input",
  CellLabel->"In[2]:="],

Cell["\<\
DefineOrthonormalBasis sets  the properties of a orthonormal basis\
\>", "Text"],

Cell[BoxData[
    \(SetCliffordBasisValueRules[\[DoubleStruckE], 3]\)], "Input",
  CellLabel->"In[4]:="],

Cell["BasisLabelsList has been updated.", "Text"],

Cell[BoxData[
    \(BasisLabelsList\)], "Input",
  CellLabel->"In[5]:="],

Cell["\<\
CliffordBasis[e,n] generates a list of all the Clifford multi-vectors of all \
the grades for a space with maximum grade n. A grade 2 vector is a bivector, \
etc.\
\>", "Text"],

Cell[BoxData[
    \(CliffordBasis[\[DoubleStruckE], 3]\)], "Input",
  CellLabel->"In[6]:="],

Cell["\<\
If we want only a particular grade we add an additional argument for the \
grade.\
\>", "Text"],

Cell[BoxData[
    \(CliffordBasis[\[DoubleStruckE], {3, 2}]\)], "Input",
  CellLabel->"In[7]:="],

Cell["Let's show the content in the memory:", "Text"],

Cell[BoxData[
    \(UpValues[\[DoubleStruckE]]\)], "Input",
  CellLabel->"In[8]:="],

Cell["\<\
Now we can evaluate the products of the basis vectors with  the help of \
UpValues\
\>", "Text"],

Cell[BoxData[{
    \(PVector[\[DoubleStruckE]\_3, 1] ** 
      PVector[\[DoubleStruckE]\_3, 1]\), "\[IndentingNewLine]", 
    \(% /. UpValues[\[DoubleStruckE]]\)}], "Input",
  CellLabel->"In[9]:="],

Cell[BoxData[
    \(Array[PVector[\[DoubleStruckE]\_#, 1] &, 3]\)], "Input",
  CellLabel->"In[11]:="],

Cell["The same work with BasisSimplify", "Text"],

Cell[BoxData[{
    \(PVector[\[DoubleStruckE]\_3, 1] ** 
      PVector[\[DoubleStruckE]\_3, 1]\), "\[IndentingNewLine]", 
    \(% // BasisSimplify[\[DoubleStruckE]]\)}], "Input",
  CellLabel->"In[12]:="],

Cell[BoxData[{
    \(PVector[\[DoubleStruckE]\_3, 1]\[CenterDot]
      PVector[\[DoubleStruckE]\_3, 1]\), "\[IndentingNewLine]", 
    \(% // BasisSimplify[\[DoubleStruckE]]\)}], "Input",
  CellLabel->"In[14]:="],

Cell[BoxData[{
    \(PVector[\[DoubleStruckE]\_1, 1]\[CenterDot]
      PVector[\[DoubleStruckE]\_3, 1]\), "\[IndentingNewLine]", 
    \(% // BasisSimplify[\[DoubleStruckE]]\)}], "Input",
  CellLabel->"In[16]:="],

Cell[BoxData[{
    \(PVector[\[DoubleStruckE]\_1, 1] ** 
      PVector[\[DoubleStruckE]\_3, 1]\), "\[IndentingNewLine]", 
    \(% // BasisSimplify[\[DoubleStruckE]]\)}], "Input",
  CellLabel->"In[18]:="],

Cell["Let's play with the basis", "Text"],

Cell[BoxData[{
    \(PVector[\[DoubleStruckE]\_1, 1] ** PVector[\[DoubleStruckE]\_2, 1] ** 
      PVector[\[DoubleStruckE]\_3, 1]\), "\[IndentingNewLine]", 
    \(\(% // GeometricPToWI\) // GeometricPToWI\), "\[IndentingNewLine]", 
    \(answer = % // BasisSimplify[\[DoubleStruckE]]\)}], "Input",
  CellLabel->"In[20]:="],

Cell["The first term should be zero as we are going to prove next.", "Text"],

Cell[BoxData[{
    \(answer[\([1]\)]\), "\[IndentingNewLine]", 
    \(\(% // BasisInnerToGeometricP\) // 
      WedgeToGeometricP\), "\[IndentingNewLine]", 
    \(\(\(% // CliffordExpand\) // CliffordSimplify\) // 
      CliffordExpand\), "\[IndentingNewLine]", 
    \(% // BasisSimplify[\[DoubleStruckE]]\)}], "Input",
  CellLabel->"In[23]:="],

Cell["Other exercise", "Text"],

Cell[BoxData[{
    \(\((\(-1\)*
          PVector[\[DoubleStruckE]\_3, 1] ** 
            PVector[\[DoubleStruckE]\_2, 1])\)\[CenterDot]
      PVector[\[DoubleStruckE]\_1, 1]\), "\[IndentingNewLine]", 
    \(% // CliffordSimplify\), "\[IndentingNewLine]", 
    \(% // BasisInnerToGeometricP\), "\[IndentingNewLine]", 
    \(% // BasisSimplify[\[DoubleStruckE]]\)}], "Input",
  CellLabel->"In[27]:="],

Cell["Other variations", "Text"],

Cell[BoxData[{
    \(PVector[\[DoubleStruckE]\_1, 1] ** PVector[\[DoubleStruckE]\_2, 1] ** 
      PVector[\[DoubleStruckE]\_1, 1]\), "\[IndentingNewLine]", 
    \(\(BasisSimplify[\[DoubleStruckE]]\)[%]\)}], "Input",
  CellLabel->"In[31]:="],

Cell[BoxData[{
    \(PVector[\[DoubleStruckE]\_1, 1] ** PVector[\[DoubleStruckE]\_2, 1] ** 
      PVector[\[DoubleStruckE]\_1, 1] ** 
      PVector[\[DoubleStruckE]\_2, 1]\), "\[IndentingNewLine]", 
    \(\(BasisSimplify[\[DoubleStruckE]]\)[%]\)}], "Input",
  CellLabel->"In[33]:="],

Cell[BoxData[{
    \(PVector[\[DoubleStruckE]\_2, 1] ** 
      PVector[\[DoubleStruckE]\_1, 1]\), "\[IndentingNewLine]", 
    \(\(BasisSimplify[\[DoubleStruckE]]\)[%]\)}], "Input",
  CellLabel->"In[35]:="],

Cell[BoxData[{
    \(PVector[\[DoubleStruckE]\_1, 1] ** PVector[\[DoubleStruckE]\_2, 1] ** 
      PVector[\[DoubleStruckE]\_1, 1] ** 
      PVector[\[DoubleStruckE]\_2, 1]\), "\[IndentingNewLine]", 
    \(\(BasisSimplify[\[DoubleStruckE]]\)[%]\)}], "Input",
  CellLabel->"In[37]:="],

Cell["\<\
A vector in the defined space can be expressed as a linear supperposition of \
the basis.\
\>", "Text"],

Cell[BoxData[
    \(SomeValues = {\ \[IndentingNewLine]PVector[a, 1] \[Rule] 
          Evaluate[
            au[i] PVector[\[DoubleStruckE]\_i, 1] // 
              SumExpansion[{i}]], \[IndentingNewLine]PVector[b, 1] \[Rule] 
          Evaluate[
            bu[i] PVector[\[DoubleStruckE]\_i, 1] // 
              SumExpansion[{i}]]\[IndentingNewLine]}\)], "Input",
  CellLabel->"In[39]:="],

Cell["The real part which is the scalar product", "Text"],

Cell[BoxData[{
    \(RealPart[PVector[a, 1] ** PVector[b, 1]] /. 
      SomeValues\), "\[IndentingNewLine]", 
    \(ExpandRealPart[%]\), "\[IndentingNewLine]", 
    \(CliffordExpand[%]\), "\[IndentingNewLine]", 
    \(\(BasisSimplify[\[DoubleStruckE]]\)[%] // Expand\)}], "Input",
  CellLabel->"In[40]:="],

Cell["The imaginary part", "Text"],

Cell[BoxData[{
    \(\(\(ImaginaryPart[PVector[a, 1] ** PVector[b, 1]] /. 
      SomeValues\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(Print["\<Expanding the Imaginary part:\>"];\)\), \
"\[IndentingNewLine]", 
    \(\(\(ExpandImaginaryPart[%%]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(Print["\<Expanding the products:\>"];\)\), "\[IndentingNewLine]", 
    \(\(\(CliffordExpand[%%] // Expand\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(Print["\<Simplifying the vector product of the basis:\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(\(\(BasisSimplify[\[DoubleStruckE]]\)[%%] // 
      Expand\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Print["\<Collecting terms\>"]\), "\[IndentingNewLine]", 
    \(Collect[%%, CliffordBasis[\[DoubleStruckE], {3, 2}]]\)}], "Input",
  CellLabel->"In[44]:="]
}, Closed]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 800}, {0, 527}},
ScreenStyleEnvironment->"Working",
WindowToolbars->{},
WindowSize->{732, 500},
WindowMargins->{{-2, Automatic}, {Automatic, 0}},
ShowSelection->True,
CommonDefaultFormatTypes->{"Output"->TraditionalForm},
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Function?"->{
    Cell[1705, 50, 73, 1, 31, "ObjectName",
      CellTags->"Function?"],
    Cell[1781, 53, 186, 6, 32, "Usage",
      CellTags->"Function?"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Function?", 10415, 318}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1705, 50, 73, 1, 31, "ObjectName",
  CellTags->"Function?"],
Cell[1781, 53, 186, 6, 32, "Usage",
  CellTags->"Function?"],
Cell[1970, 61, 72, 0, 31, "MathCaption"],
Cell[2045, 63, 129, 3, 31, "MathCaption"],
Cell[2177, 68, 134, 3, 31, "MathCaption"],
Cell[2314, 73, 547, 18, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[2886, 95, 34, 0, 40, "ExampleSection"],
Cell[2923, 97, 98, 2, 29, "Input"],
Cell[3024, 101, 97, 2, 25, "Text"],
Cell[3124, 105, 161, 3, 49, "Input"],
Cell[3288, 110, 90, 2, 25, "Text"],
Cell[3381, 114, 104, 2, 29, "Input"],
Cell[3488, 118, 49, 0, 25, "Text"],
Cell[3540, 120, 72, 2, 29, "Input"],
Cell[3615, 124, 186, 4, 42, "Text"],
Cell[3804, 130, 91, 2, 29, "Input"],
Cell[3898, 134, 105, 3, 25, "Text"],
Cell[4006, 139, 96, 2, 29, "Input"],
Cell[4105, 143, 53, 0, 25, "Text"],
Cell[4161, 145, 83, 2, 29, "Input"],
Cell[4247, 149, 106, 3, 25, "Text"],
Cell[4356, 154, 197, 4, 49, "Input"],
Cell[4556, 160, 101, 2, 29, "Input"],
Cell[4660, 164, 48, 0, 25, "Text"],
Cell[4711, 166, 203, 4, 49, "Input"],
Cell[4917, 172, 211, 4, 49, "Input"],
Cell[5131, 178, 211, 4, 49, "Input"],
Cell[5345, 184, 203, 4, 49, "Input"],
Cell[5551, 190, 41, 0, 25, "Text"],
Cell[5595, 192, 322, 5, 69, "Input"],
Cell[5920, 199, 76, 0, 25, "Text"],
Cell[5999, 201, 344, 7, 89, "Input"],
Cell[6346, 210, 30, 0, 25, "Text"],
Cell[6379, 212, 399, 8, 89, "Input"],
Cell[6781, 222, 32, 0, 25, "Text"],
Cell[6816, 224, 240, 4, 49, "Input"],
Cell[7059, 230, 282, 5, 49, "Input"],
Cell[7344, 237, 205, 4, 49, "Input"],
Cell[7552, 243, 282, 5, 49, "Input"],
Cell[7837, 250, 113, 3, 25, "Text"],
Cell[7953, 255, 392, 8, 89, "Input"],
Cell[8348, 265, 57, 0, 25, "Text"],
Cell[8408, 267, 305, 6, 89, "Input"],
Cell[8716, 275, 34, 0, 25, "Text"],
Cell[8753, 277, 884, 18, 269, "Input"]
}, Closed]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

