(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     52690,       1305]*)
(*NotebookOutlinePosition[     53421,       1330]*)
(*  CellTagsIndexPosition[     53377,       1326]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Paravectors and Special Relativity", "Title"],

Cell[TextData[{
  StyleBox[" Renan Cabrera\n",
    FontSize->18],
  StyleBox["Graduate student\nPhysics Dept., University of Windsor\nWindsor, \
ON, Canada N9B 3P4\nrencabla@ceibo.entelnet.bo\ncabrer7@uwindsor.ca\n\
December/2003",
    FontSize->14]
}], "Subtitle"],

Cell["\<\
Special Relativity is traditionally studied using tensor calculus starting \
from the definition of the metric of the Minkovsky space which is a four \
dimensional space. There are two compiting approaches to apply Clifford \
Algebra (or Geometric Algebra). The first approach defines four orthonormal \
vectors running from zero to 3, where the zero unitary vector is associated \
to the time.This space is called Space Time Algebra (STA). The second \
approach still uses the the three dimensional space basis where the zero \
component is a scalar. This space is called Algebraic Physical Space (APS). \
In this notebook we use APS which has the advantage that we do not have to \
impose the Minkovsky because it appears naturally as a consequence of the \
properties of the algebra itself. Personally I like this approach because it \
breaks out naturally the symmetry between the time and the three dimesional \
space.\
\>", "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell[BoxData[
    \(Needs["\<TCliffordAlgebra1`TClifford`\>"]\)], "Input"],

Cell[BoxData[
    \(DeclareBaseIndices[{0, 1, 2, 3}]\)], "Input"],

Cell["Initial Settting", "Text"],

Cell[BoxData[{
    \(SetCliffordBasisValueRules[\[DoubleStruckE], 
      3]\), "\[IndentingNewLine]", 
    \(SetParavectorBasisValues[\[DoubleStruckE], 
      Length@BaseIndices]\), "\[IndentingNewLine]", 
    \(\(labs = {x, \[Delta], 
          g, \[CapitalGamma]};\)\), "\[IndentingNewLine]", 
    \(DefineTensorShortcuts[{{x, B}, 1}, {F, 2}]\)}], "Input"],

Cell[CellGroupData[{

Cell["Paravector Basis", "Section"],

Cell[TextData[{
  "The Paravector basis is expanded in terms of the vector basis plus one \
additional term corresponding to the scalar part. This basically means that \
",
  Cell[BoxData[
      \(TraditionalForm\`\[DoubleStruckE]\_0\)]],
  "= 1."
}], "Text"],

Cell[BoxData[{
    \(PVector[
      Subscript[\[DoubleStruckE], i], {0, 1}]\), "\[IndentingNewLine]", 
    \(Table[%, {i, 0, 3}] // BasisSimplify[\[DoubleStruckE]]\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["BiParavector Basis", "Section"],

Cell[TextData[{
  "The BiParavector basis is expanded as the vector part of the geometric \
product of the vector and paravector part:\n",
  Cell[BoxData[
      FormBox[
        TagBox[
          StyleBox[
            FormBox[
              TagBox[
                SubscriptBox[
                  RowBox[{"\[LeftAngleBracket]", 
                    FormBox[
                      RowBox[{
                        FormBox[
                          TagBox[
                            StyleBox[
                              InterpretationBox[\(\[DoubleStruckE]\_\[Mu]\),
                                SequenceForm[ 
                                  Subscript[ \[DoubleStruckE], \[Mu]]],
                                Editable->False],
                              FontColor->RGBColor[0.589853, 0, 0.292973],
                              Magnification->1],
                            (
                            StyleForm[ #, FontColor -> 
                              RGBColor[ .58985299999999996, 
                                0, .29297299999999998], Magnification -> 
                              1.0]&)],
                          "TraditionalForm"], "\[Diamond]", 
                        FormBox[
                          OverscriptBox[
                            FormBox[
                              TagBox[
                                StyleBox[
                                  
                                  InterpretationBox[\(\[DoubleStruckE]\_\[Nu]\
\),
                                    SequenceForm[ 
                                      Subscript[ \[DoubleStruckE], \[Nu]]],
                                    Editable->False],
                                  FontColor->RGBColor[0.589853, 0, 0.292973],
                                  Magnification->1],
                                (
                                StyleForm[ #, FontColor -> 
                                  RGBColor[ .58985299999999996, 
                                    0, .29297299999999998], Magnification -> 
                                  1.0]&)],
                              "TraditionalForm"], "\<\"_\"\>"],
                          "TraditionalForm"]}],
                      "TraditionalForm"], "\[RightAngleBracket]"}], "V"],
                DisplayForm],
              "TraditionalForm"],
            FontFamily->"Courier",
            FontSize->16],
          (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
        TraditionalForm]]]
}], "Text"],

Cell[BoxData[{
    \(\(\(VectorPart[
      PVector[Subscript[\[DoubleStruckE], \[Mu]], {0, 1}] ** 
        BarConjugation[
          PVector[Subscript[\[DoubleStruckE], \[Nu]], {0, 
              1}]]]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Table[\ 
            ExpandVectorPart[% // BasisSimplify[\[DoubleStruckE]]], {\[Mu], 
              0, 3}, {\[Nu], 0, 3}] // EvaluateBarConjugation\) // 
        CliffordSimplify\) // BasisSimplify[\[DoubleStruckE]]\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["TriParavector Basis", "Section"],

Cell[TextData[{
  "The TriParavector basis is expanded as the imaginary part of the geometric \
product of the vector and paravector part:\n\t",
  Cell[BoxData[
      FormBox[
        TagBox[
          StyleBox[
            FormBox[
              TagBox[
                SubscriptBox[
                  RowBox[{"\[LeftAngleBracket]", 
                    FormBox[
                      RowBox[{
                        FormBox[
                          TagBox[
                            StyleBox[
                              
                              InterpretationBox[\(\[DoubleStruckE]\_\[Lambda]\
\),
                                SequenceForm[ 
                                  Subscript[ \[DoubleStruckE], \[Lambda]]],
                                Editable->False],
                              FontColor->RGBColor[0.589853, 0, 0.292973],
                              Magnification->1],
                            (
                            StyleForm[ #, FontColor -> 
                              RGBColor[ .58985299999999996, 
                                0, .29297299999999998], Magnification -> 
                              1.0]&)],
                          "TraditionalForm"], "\[Diamond]", 
                        FormBox[
                          OverscriptBox[
                            FormBox[
                              TagBox[
                                StyleBox[
                                  
                                  InterpretationBox[\(\[DoubleStruckE]\_\[Mu]\
\),
                                    SequenceForm[ 
                                      Subscript[ \[DoubleStruckE], \[Mu]]],
                                    Editable->False],
                                  FontColor->RGBColor[0.589853, 0, 0.292973],
                                  Magnification->1],
                                (
                                StyleForm[ #, FontColor -> 
                                  RGBColor[ .58985299999999996, 
                                    0, .29297299999999998], Magnification -> 
                                  1.0]&)],
                              "TraditionalForm"], "\<\"_\"\>"],
                          "TraditionalForm"], "\[Diamond]", 
                        FormBox[
                          TagBox[
                            StyleBox[
                              InterpretationBox[\(\[DoubleStruckE]\_\[Nu]\),
                                SequenceForm[ 
                                  Subscript[ \[DoubleStruckE], \[Nu]]],
                                Editable->False],
                              FontColor->RGBColor[0.589853, 0, 0.292973],
                              Magnification->1],
                            (
                            StyleForm[ #, FontColor -> 
                              RGBColor[ .58985299999999996, 
                                0, .29297299999999998], Magnification -> 
                              1.0]&)],
                          "TraditionalForm"]}],
                      "TraditionalForm"], "\[RightAngleBracket]"}], 
                  "\[ScriptCapitalI]"],
                DisplayForm],
              "TraditionalForm"],
            FontFamily->"Courier",
            FontSize->16],
          (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
        TraditionalForm]]]
}], "Text"],

Cell[BoxData[{
    \(\(\(ImaginaryPart[
      PVector[Subscript[\[DoubleStruckE], \[Lambda]], {0, 1}] ** 
        BarConjugation@PVector[Subscript[\[DoubleStruckE], \[Mu]], {0, 1}] ** 
        PVector[Subscript[\[DoubleStruckE], \[Nu]], {0, 
            1}]]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(Table[\ 
      ExpandImaginaryPart[% // BasisSimplify[\[DoubleStruckE]]] // 
        BasisSimplify[\[DoubleStruckE]], {\[Lambda], 0, 3}, {\[Mu], 0, 
        3}, {\[Nu], 0, 3}]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Union@Flatten[%]\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Metric", "Section"],

Cell[TextData[{
  "We can recover the metric taking the scalar part of the geometric product \
of  each basis paravector  and its barconjugated. This operation is the \
generalization of the inner product.\n\t",
  Cell[BoxData[
      FormBox[
        TagBox[
          StyleBox[
            FormBox[
              TagBox[
                SubscriptBox[
                  RowBox[{"\[LeftAngleBracket]", 
                    FormBox[
                      RowBox[{
                        FormBox[
                          TagBox[
                            StyleBox[
                              InterpretationBox[\(\[DoubleStruckE]\_\[Mu]\),
                                SequenceForm[ 
                                  Subscript[ \[DoubleStruckE], \[Mu]]],
                                Editable->False],
                              FontColor->RGBColor[0.589853, 0, 0.292973],
                              Magnification->1],
                            (
                            StyleForm[ #, FontColor -> 
                              RGBColor[ .58985299999999996, 
                                0, .29297299999999998], Magnification -> 
                              1.0]&)],
                          "TraditionalForm"], "\[Diamond]", 
                        FormBox[
                          OverscriptBox[
                            FormBox[
                              TagBox[
                                StyleBox[
                                  
                                  InterpretationBox[\(\[DoubleStruckE]\_\[Nu]\
\),
                                    SequenceForm[ 
                                      Subscript[ \[DoubleStruckE], \[Nu]]],
                                    Editable->False],
                                  FontColor->RGBColor[0.589853, 0, 0.292973],
                                  Magnification->1],
                                (
                                StyleForm[ #, FontColor -> 
                                  RGBColor[ .58985299999999996, 
                                    0, .29297299999999998], Magnification -> 
                                  1.0]&)],
                              "TraditionalForm"], "\<\"_\"\>"],
                          "TraditionalForm"]}],
                      "TraditionalForm"], "\[RightAngleBracket]"}], "S"],
                DisplayForm],
              "TraditionalForm"],
            FontFamily->"Courier",
            FontSize->16],
          (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
        TraditionalForm]]]
}], "Text"],

Cell[BoxData[{
    \(ScalarPart[
      PVector[Subscript[\[DoubleStruckE], \[Mu]], {0, 1}] ** 
        BarConjugation[
          PVector[Subscript[\[DoubleStruckE], \[Nu]], {0, 
              1}]]]\), "\[IndentingNewLine]", 
    \(Table[\ 
        ExpandScalarPart[% // BasisSimplify[\[DoubleStruckE]]], {\[Mu], 0, 
          3}, {\[Nu], 0, 3}] // 
      BasisSimplify[\[DoubleStruckE]]\), "\[IndentingNewLine]", 
    \(% /. PVector[Subscript[\[DoubleStruckE], 0], 0] \[Rule] 1\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Testing Some identities", "Section"],

Cell[CellGroupData[{

Cell["\<\
Perpendicular part of a real paravector lying  on a pure biparavector \
\>", "Subsection"],

Cell[TextData[{
  "Let's  test the  following identity:\n\t\t\t\t    ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          TagBox[
            StyleBox[
              FormBox[
                TagBox[
                  SubscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                      FormBox[
                        RowBox[{
                          FormBox[
                            TagBox[
                              SubscriptBox[
                                RowBox[{"\[LeftAngleBracket]", 
                                  FormBox[
                                    RowBox[{
                                      FormBox[
                                        TagBox[
                                        StyleBox[
                                        InterpretationBox["a",
                                        SequenceForm[ a],
                                        Editable->False],
                                        FontColor->RGBColor[0.589853, 0, 
                                        0.292973],
                                        Magnification->1],
                                        (
                                        StyleForm[ #, FontColor -> 
                                        RGBColor[ .58985299999999996, 
                                        0, .29297299999999998], Magnification -> 
                                        1.0]&)],
                                        "TraditionalForm"], "\[Diamond]", 
                                      FormBox[
                                        OverscriptBox[
                                        FormBox[
                                        TagBox[
                                        StyleBox[
                                        InterpretationBox["b",
                                        SequenceForm[ b],
                                        Editable->False],
                                        FontColor->RGBColor[0.589853, 0, 
                                        0.292973],
                                        Magnification->1],
                                        (StyleForm[ #, FontColor -> 
                                        RGBColor[ .58985299999999996, 
                                        0, .29297299999999998], Magnification -> 
                                        1.0]&)],
                                        "TraditionalForm"], "\<\"_\"\>"],
                                        "TraditionalForm"]}],
                                    "TraditionalForm"], 
                                  "\[RightAngleBracket]"}], "V"],
                              DisplayForm],
                            "TraditionalForm"], "\[Diamond]", 
                          FormBox[
                            TagBox[
                              StyleBox[
                                InterpretationBox["c",
                                  SequenceForm[ c],
                                  Editable->False],
                                FontColor->RGBColor[0.589853, 0, 0.292973],
                                Magnification->1],
                              (
                              StyleForm[ #, FontColor -> 
                                RGBColor[ .58985299999999996, 
                                  0, .29297299999999998], Magnification -> 
                                1.0]&)],
                            "TraditionalForm"]}],
                        "TraditionalForm"], "\[RightAngleBracket]"}], 
                    "\[ScriptCapitalR]"],
                  DisplayForm],
                "TraditionalForm"],
              FontFamily->"Courier",
              FontSize->16],
            (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], "=", 
          TagBox[
            StyleBox[
              RowBox[{
                FormBox[
                  RowBox[{
                    FormBox[
                      TagBox[
                        SubscriptBox[
                          RowBox[{"\[LeftAngleBracket]", 
                            FormBox[
                              RowBox[{
                                FormBox[
                                  TagBox[
                                    StyleBox[
                                      InterpretationBox["c",
                                        SequenceForm[ c],
                                        Editable->False],
                                      FontColor->RGBColor[0.589853, 0, 
                                      0.292973],
                                      Magnification->1],
                                    (
                                    StyleForm[ #, FontColor -> 
                                      RGBColor[ .58985299999999996, 
                                        0, .29297299999999998], Magnification -> 
                                      1.0]&)],
                                  "TraditionalForm"], "\[Diamond]", 
                                FormBox[
                                  OverscriptBox[
                                    FormBox[
                                      TagBox[
                                        StyleBox[
                                        InterpretationBox["b",
                                        SequenceForm[ b],
                                        Editable->False],
                                        FontColor->RGBColor[0.589853, 0, 
                                        0.292973],
                                        Magnification->1],
                                        (
                                        StyleForm[ #, FontColor -> 
                                        RGBColor[ .58985299999999996, 
                                        0, .29297299999999998], Magnification -> 
                                        1.0]&)],
                                      "TraditionalForm"], "\<\"_\"\>"],
                                  "TraditionalForm"]}],
                              "TraditionalForm"], "\[RightAngleBracket]"}], 
                          "S"],
                        DisplayForm],
                      "TraditionalForm"], "\[Diamond]", 
                    FormBox[
                      TagBox[
                        StyleBox[
                          InterpretationBox["a",
                            SequenceForm[ a],
                            Editable->False],
                          FontColor->RGBColor[0.589853, 0, 0.292973],
                          Magnification->1],
                        (
                        StyleForm[ #, FontColor -> 
                          RGBColor[ .58985299999999996, 
                            0, .29297299999999998], Magnification -> 1.0]&)],
                      "TraditionalForm"]}],
                  "TraditionalForm"], "-", 
                FormBox[
                  RowBox[{
                    FormBox[
                      TagBox[
                        SubscriptBox[
                          RowBox[{"\[LeftAngleBracket]", 
                            FormBox[
                              RowBox[{
                                FormBox[
                                  TagBox[
                                    StyleBox[
                                      InterpretationBox["a",
                                        SequenceForm[ a],
                                        Editable->False],
                                      FontColor->RGBColor[0.589853, 0, 
                                      0.292973],
                                      Magnification->1],
                                    (
                                    StyleForm[ #, FontColor -> 
                                      RGBColor[ .58985299999999996, 
                                        0, .29297299999999998], Magnification -> 
                                      1.0]&)],
                                  "TraditionalForm"], "\[Diamond]", 
                                FormBox[
                                  OverscriptBox[
                                    FormBox[
                                      TagBox[
                                        StyleBox[
                                        InterpretationBox["c",
                                        SequenceForm[ c],
                                        Editable->False],
                                        FontColor->RGBColor[0.589853, 0, 
                                        0.292973],
                                        Magnification->1],
                                        (
                                        StyleForm[ #, FontColor -> 
                                        RGBColor[ .58985299999999996, 
                                        0, .29297299999999998], Magnification -> 
                                        1.0]&)],
                                      "TraditionalForm"], "\<\"_\"\>"],
                                  "TraditionalForm"]}],
                              "TraditionalForm"], "\[RightAngleBracket]"}], 
                          "S"],
                        DisplayForm],
                      "TraditionalForm"], "\[Diamond]", 
                    FormBox[
                      TagBox[
                        StyleBox[
                          InterpretationBox["b",
                            SequenceForm[ b],
                            Editable->False],
                          FontColor->RGBColor[0.589853, 0, 0.292973],
                          Magnification->1],
                        (
                        StyleForm[ #, FontColor -> 
                          RGBColor[ .58985299999999996, 
                            0, .29297299999999998], Magnification -> 1.0]&)],
                      "TraditionalForm"]}],
                  "TraditionalForm"]}],
              FontFamily->"Courier",
              FontSize->16],
            (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)]}], 
        TraditionalForm]]]
}], "Text"],

Cell["Right expression:", "Text"],

Cell[BoxData[{
    \(RealPart[\[IndentingNewLine]VectorPart[
          PVector[a, {0, 1}] ** BarConjugation[PVector[b, {0, 1}]]] ** 
        PVector[c, {0, 1}]\[IndentingNewLine]]\), "\[IndentingNewLine]", 
    \(\(\(\(\(\(% // ExpandRealPart\) // ExpandVectorPart\) // 
            EvaluateSuperDagger\) // CliffordExpand\) // CliffordSimplify\) // 
      Expand\)}], "Input"],

Cell["Left expression: First way", "Text"],

Cell[BoxData[{
    \(PVector[a, {0, 1}] ** 
        ScalarPart[
          BarConjugation[PVector[b, {0, 1}]] ** PVector[c, {0, 1}]] - 
      PVector[b, {0, 1}] ** 
        ScalarPart[
          BarConjugation[PVector[c, {0, 1}]] ** 
            PVector[a, {0, 1}]]\), "\[IndentingNewLine]", 
    \(Ans1 = \(% // ExpandScalarPart\) // CliffordExpand\)}], "Input"],

Cell["Left expression: Alternative way", "Text"],

Cell[BoxData[{
    \(ScalarPart[PVector[c, {0, 1}] ** BarConjugation[PVector[b, {0, 1}]]] ** 
        PVector[a, {0, 1}] - 
      ScalarPart[PVector[a, {0, 1}] ** BarConjugation[PVector[c, {0, 1}]]] ** 
        PVector[b, {0, 1}]\), "\[IndentingNewLine]", 
    \(Ans2 = \(% // ExpandScalarPart\) // CliffordExpand\)}], "Input"],

Cell["\<\
And we recover the firt expression again from the two alternatives:\
\>", "Text"],

Cell[BoxData[
    \(\((Ans1 + Ans2)\)/2 // Expand\)], "Input"],

Cell[TextData[{
  "Now as another task let's test the perpendicularity:\n\n\t\t\t\t",
  Cell[BoxData[
      FormBox[
        TagBox[
          StyleBox[
            FormBox[
              TagBox[
                SubscriptBox[
                  RowBox[{"\[LeftAngleBracket]", 
                    FormBox[
                      RowBox[{
                        FormBox[
                          TagBox[
                            RowBox[{" ", 
                              SubscriptBox[
                                RowBox[{"\[LeftAngleBracket]", 
                                  FormBox[
                                    RowBox[{
                                      FormBox[
                                        TagBox[
                                        SubscriptBox[
                                        RowBox[{"\[LeftAngleBracket]", 
                                        FormBox[
                                        RowBox[{
                                        FormBox[
                                        TagBox[
                                        StyleBox[
                                        InterpretationBox["a",
                                        SequenceForm[ a],
                                        Editable->False],
                                        FontColor->RGBColor[0.589853, 0, 
                                        0.292973],
                                        Magnification->1],
                                        (
                                        StyleForm[ #, FontColor -> 
                                        RGBColor[ .58985299999999996, 
                                        0, .29297299999999998], Magnification -> 
                                        1.0]&)],
                                        "TraditionalForm"], "\[Diamond]", 
                                        FormBox[
                                        OverscriptBox[
                                        FormBox[
                                        TagBox[
                                        StyleBox[
                                        InterpretationBox["b",
                                        SequenceForm[ b],
                                        Editable->False],
                                        FontColor->RGBColor[0.589853, 0, 
                                        0.292973],
                                        Magnification->1],
                                        (
                                        StyleForm[ #, FontColor -> 
                                        RGBColor[ .58985299999999996, 
                                        0, .29297299999999998], Magnification -> 
                                        1.0]&)],
                                        "TraditionalForm"], "\<\"_\"\>"],
                                        "TraditionalForm"]}],
                                        "TraditionalForm"], 
                                        "\[RightAngleBracket]"}], "V"],
                                        DisplayForm],
                                        "TraditionalForm"], "\[Diamond]", 
                                      FormBox[
                                        TagBox[
                                        StyleBox[
                                        InterpretationBox["c",
                                        SequenceForm[ c],
                                        Editable->False],
                                        FontColor->RGBColor[0.589853, 0, 
                                        0.292973],
                                        Magnification->1],
                                        (
                                        StyleForm[ #, FontColor -> 
                                        RGBColor[ .58985299999999996, 
                                        0, .29297299999999998], Magnification -> 
                                        1.0]&)],
                                        "TraditionalForm"]}],
                                    "TraditionalForm"], 
                                  "\[RightAngleBracket]"}], 
                                "\[ScriptCapitalR]"]}],
                            DisplayForm],
                          "TraditionalForm"], "\[Diamond]", 
                        FormBox[
                          OverscriptBox[
                            FormBox[
                              TagBox[
                                StyleBox[
                                  InterpretationBox["c",
                                    SequenceForm[ c],
                                    Editable->False],
                                  FontColor->RGBColor[0.589853, 0, 0.292973],
                                  Magnification->1],
                                (
                                StyleForm[ #, FontColor -> 
                                  RGBColor[ .58985299999999996, 
                                    0, .29297299999999998], Magnification -> 
                                  1.0]&)],
                              "TraditionalForm"], "\<\"_\"\>"],
                          "TraditionalForm"]}],
                      "TraditionalForm"], "\[RightAngleBracket]"}], "S"],
                DisplayForm],
              "TraditionalForm"],
            FontFamily->"Courier",
            FontSize->16],
          (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
        TraditionalForm]]]
}], "Text"],

Cell[BoxData[{
    \(ScalarPart[\[IndentingNewLine]RealPart[\[IndentingNewLine]VectorPart[
              PVector[a, {0, 1}] ** BarConjugation[PVector[b, {0, 1}]]] ** 
            PVector[c, {0, 1}]\[IndentingNewLine]] ** 
        BarConjugation[
          PVector[c, {0, 1}]]\[IndentingNewLine]]\), "\[IndentingNewLine]", 
    \(\(\(\(% // ExpandVectorPart\) // CliffordExpand\) // CliffordExpand\) // 
      CliffordSimplify\), "\[IndentingNewLine]", 
    \(\(\(% // ExpandRealPart\) // CliffordExpand\) // 
      CliffordExpand\), "\[IndentingNewLine]", 
    \(% // ExpandScalarPart\), "\[IndentingNewLine]", 
    \(\((% /. 
          PVector[c, {0, 1}] ** BarConjugation[PVector[c, {0, 1}]] \[Rule] 
            c)\) // CliffordSimplify\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
The Dual of a Paravolume is orthogonal to any of the paravectors making the \
paravolume\
\>", "Subsection"],

Cell["The dual of the paravolume is:", "Text"],

Cell[BoxData[
    \(\(-I\)*
      RealPart[\[IndentingNewLine]VectorPart[
            PVector[a, {0, 1}] ** BarConjugation[PVector[b, {0, 1}]]] ** 
          PVector[c, {0, 1}]\[IndentingNewLine]]\)], "Input"],

Cell[TextData[{
  "Let's take the scalar product with respect to ",
  Cell[BoxData[
      FormBox[
        TagBox[
          StyleBox[
            FormBox[
              TagBox[
                FormBox[
                  FormBox[
                    TagBox[
                      FormBox[
                        FormBox[
                          TagBox[
                            StyleBox[
                              InterpretationBox["a",
                                SequenceForm[ a],
                                Editable->False],
                              FontColor->RGBColor[0.589853, 0, 0.292973],
                              Magnification->1],
                            (
                            StyleForm[ #, FontColor -> 
                              RGBColor[ .58985299999999996, 
                                0, .29297299999999998], Magnification -> 
                              1.0]&)],
                          "TraditionalForm"],
                        "TraditionalForm"],
                      DisplayForm],
                    "TraditionalForm"],
                  "TraditionalForm"],
                DisplayForm],
              "TraditionalForm"],
            FontFamily->"Courier",
            FontSize->16],
          (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
        TraditionalForm]]]
}], "Text"],

Cell[BoxData[{
    \(ScalarPart[\[IndentingNewLine]\(-I\)*
        RealPart[\[IndentingNewLine]VectorPart[
                PVector[a, {0, 1}] ** BarConjugation[PVector[b, {0, 1}]]] ** 
              PVector[c, {0, 1}]\[IndentingNewLine]]\[IndentingNewLine] ** 
          BarConjugation[PVector[c, {0, 1}]]]\), "\[IndentingNewLine]", 
    \(\(\(\(% // ExpandVectorPart\) // CliffordExpand\) // CliffordExpand\) // 
      CliffordSimplify\), "\[IndentingNewLine]", 
    \(\(\(% // ExpandRealPart\) // CliffordExpand\) // 
      CliffordExpand\), "\[IndentingNewLine]", 
    \(% // ExpandScalarPart\), "\[IndentingNewLine]", 
    \(\((% /. 
          PVector[c, {0, 1}] ** BarConjugation[PVector[c, {0, 1}]] \[Rule] 
            c)\) // CliffordSimplify\)}], "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Reflections in Space Time", "Section"],

Cell[TextData[{
  "Let's define a function that will reflect a paravector along a non-null \
paravector:\n\t\t\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[
            RowBox[{
              RowBox[{"-", 
                FractionBox["1", 
                  StyleBox[
                    RowBox[{
                      FormBox[
                        TagBox[
                          StyleBox[
                            InterpretationBox["p",
                              SequenceForm[ p],
                              Editable->False],
                            FontColor->RGBColor[0.589853, 0, 0.292973],
                            Magnification->1],
                          (
                          StyleForm[ #, FontColor -> 
                            RGBColor[ .58985299999999996, 
                              0, .29297299999999998], Magnification -> 
                            1.0]&)],
                        "TraditionalForm"], " ", "\[Diamond]", " ", 
                      FormBox[
                        OverscriptBox[
                          FormBox[
                            TagBox[
                              StyleBox[
                                InterpretationBox["p",
                                  SequenceForm[ p],
                                  Editable->False],
                                FontColor->RGBColor[0.589853, 0, 0.292973],
                                Magnification->1],
                              (
                              StyleForm[ #, FontColor -> 
                                RGBColor[ .58985299999999996, 
                                  0, .29297299999999998], Magnification -> 
                                1.0]&)],
                            "TraditionalForm"], "\<\"_\"\>"],
                        "TraditionalForm"]}],
                    FontSize->14]]}], 
              TagBox[
                StyleBox[
                  InterpretationBox["p",
                    SequenceForm[ p],
                    Editable->False],
                  FontColor->RGBColor[0.589853, 0, 0.292973],
                  Magnification->1],
                (
                StyleForm[ #, FontColor -> 
                  RGBColor[ .58985299999999996, 0, .29297299999999998], 
                  Magnification -> 1.0]&)]}],
            "TraditionalForm"], "\[Diamond]", 
          FormBox[
            OverscriptBox[
              FormBox[
                TagBox[
                  StyleBox[
                    InterpretationBox["x",
                      SequenceForm[ x],
                      Editable->False],
                    FontColor->RGBColor[0, 0, 0.996109]],
                  (
                  StyleForm[ #, FontColor -> RGBColor[ 
                    0, 0, .99610900000000002]]&)],
                "TraditionalForm"], "\<\"_\"\>"],
            "TraditionalForm"], "\[Diamond]", 
          FormBox[
            TagBox[
              StyleBox[
                InterpretationBox["p",
                  SequenceForm[ p],
                  Editable->False],
                FontColor->RGBColor[0.589853, 0, 0.292973],
                Magnification->1],
              (
              StyleForm[ #, FontColor -> 
                RGBColor[ .58985299999999996, 0, .29297299999999998], 
                Magnification -> 1.0]&)],
            "TraditionalForm"]}], TraditionalForm]],
    FontSize->16],
  " "
}], "EmphasisText",
  TextAlignment->Left,
  TextJustification->0],

Cell[BoxData[
    \(\(Reflect[p_]\)[
        x_] := \(-p ** BarConjugation[x] ** p\)/\((p ** 
            BarConjugation[p])\)\)], "Input"],

Cell[BoxData[
    \(\(Reflect[PVector[p, {0, 1}]]\)[PVector[x]]\)], "Input"],

Cell[TextData[{
  "Time Reversal with  ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            FormBox[
              TagBox[
                StyleBox[
                  InterpretationBox["p",
                    SequenceForm[ p],
                    Editable->False],
                  FontColor->RGBColor[0.589853, 0, 0.292973],
                  Magnification->1],
                (
                StyleForm[ #, FontColor -> 
                  RGBColor[ .58985299999999996, 0, .29297299999999998], 
                  Magnification -> 1.0]&)],
              "TraditionalForm"],
            FontSize->18], "="}], TraditionalForm]],
    FontSize->16],
  Cell[BoxData[
      \(TraditionalForm\`\[DoubleStruckE]\_0\)],
    FontSize->18]
}], "Text"],

Cell[BoxData[{
    \(\(Reflect[PVector[Subscript[\[DoubleStruckE], 0], {0, 1}]]\)[
      PVector[x]]\), "\[IndentingNewLine]", 
    \(\((\((% // BasisSimplify[\[DoubleStruckE]])\) /. 
          PVector[Subscript[\[DoubleStruckE], 0], 0] \[Rule] \ 1)\) // 
      CliffordSimplify\)}], "Input"],

Cell[TextData[{
  "A spacial reflection with  ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{
            FormBox[
              TagBox[
                StyleBox[
                  InterpretationBox["p",
                    SequenceForm[ p],
                    Editable->False],
                  FontColor->RGBColor[0.589853, 0, 0.292973],
                  Magnification->1],
                (
                StyleForm[ #, FontColor -> 
                  RGBColor[ .58985299999999996, 0, .29297299999999998], 
                  Magnification -> 1.0]&)],
              "TraditionalForm"], " "}],
          FontSize->18], TraditionalForm]],
    FontSize->16],
  "= ",
  Cell[BoxData[
      FormBox[
        TagBox[
          StyleBox[
            FormBox[
              TagBox[
                StyleBox[
                  InterpretationBox[\(\[DoubleStruckE]\_1\),
                    SequenceForm[ 
                      Subscript[ \[DoubleStruckE], 1]],
                    Editable->False],
                  FontColor->RGBColor[0.589853, 0, 0.292973],
                  Magnification->1],
                (
                StyleForm[ #, FontColor -> 
                  RGBColor[ .58985299999999996, 0, .29297299999999998], 
                  Magnification -> 1.0]&)],
              "TraditionalForm"],
            FontFamily->"Courier",
            FontSize->16],
          (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
        TraditionalForm]]]
}], "Text"],

Cell[BoxData[{
    \(x*PVector[Subscript[\[DoubleStruckE], 1], 1]\  + \ 
      y*PVector[Subscript[\[DoubleStruckE], 2], 1] + 
      t\), "\[IndentingNewLine]", 
    \(\(\(PVector[
      Subscript[\[DoubleStruckE], 1], {0, 1}]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\(\(\(\(Reflect[%]\)[\ %%] // BasisSimplify[\[DoubleStruckE]]\) // 
              BasisSimplify[\[DoubleStruckE]]\) // 
            BasisSimplify[\[DoubleStruckE]]\) // CliffordExpand\) // 
        CliffordExpand\) // BasisSimplify[\[DoubleStruckE]]\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Example: Two Boosts in Different Directions", "Section"],

Cell["Let's define two boosts in different directions.", "Text"],

Cell[BoxData[
    \(Clear[B]\)], "Input"],

Cell[BoxData[
    \(ValueRules[
        B] ^= {PVector[
            B\_1] \[Rule] \ \((2 + PVector[\[DoubleStruckE]\_1, 1])\)/
            Sqrt[3], 
        PVector[B\_2] \[Rule] \ \((2 + PVector[\[DoubleStruckE]\_2, 1])\)/
            Sqrt[3]}\)], "Input"],

Cell["\<\
The product of the two boosts is not a pure boost because it contains \
imaginary parts\
\>", "Text"],

Cell[BoxData[{
    \(PVector[B\_1] ** PVector[B\_2]\), "\[IndentingNewLine]", 
    \(PVector[L] \[Rule] \ % /. ValueRules[B] // 
      CliffordExpand\), "\[IndentingNewLine]", 
    \(\(ValueRules[B] ^= Append[ValueRules[B], %];\)\)}], "Input"],

Cell[TextData[{
  "This new transformation can be written as the product of a boost and a \
rotation",
  StyleBox[" L = B\[Diamond]R",
    FontWeight->"Bold"]
}], "Text"],

Cell["\<\
Th next expression gets ride of the rotation part and is equal to the square \
of the boost, which is the proper velocity.\
\>", "Text"],

Cell[BoxData[{
    \(PVector[L] ** SuperDagger@PVector[L]\), "\[IndentingNewLine]", 
    \(% /. ValueRules[B]\), "\[IndentingNewLine]", 
    \(\(\(\(% // EvaluateSuperDagger\) // CliffordExpand\) // 
        CliffordExpand\) // CliffordSimplify\), "\[IndentingNewLine]", 
    \(PVector[u, {0, 1}] \[Rule] \ % // 
      BasisSimplify[\[DoubleStruckE]]\), "\[IndentingNewLine]", 
    \(\(ValueRules[B] ^= Append[ValueRules[B], %];\)\)}], "Input"],

Cell["The boost is recovered by taking the square root", "Text"],

Cell[BoxData[{
    \(\((PVector[u, {0, 1}] + 1)\)/
      Sqrt[2*\((ScalarPart[PVector[u, {0, 1}]] + 
              1)\)]\), "\[IndentingNewLine]", 
    \(\(\(% /. ValueRules[B] // ExpandScalarPart\) // CliffordExpand\) // 
      CliffordSimplify\), "\[IndentingNewLine]", 
    \(PVector[B] \[Rule] \ %\), "\[IndentingNewLine]", 
    \(\(ValueRules[B] ^= Append[ValueRules[B], %];\)\)}], "Input"],

Cell["Let's see if this new boost is unimodular", "Text"],

Cell[BoxData[{
    \(PVector[B] ** BarConjugation[PVector[B]]\), "\[IndentingNewLine]", 
    \(% /. ValueRules[B]\), "\[IndentingNewLine]", 
    \(% // ExpandBarConjugation\), "\[IndentingNewLine]", 
    \(\(% // CliffordExpand\) // BasisSimplify[\[DoubleStruckE]]\)}], "Input"],

Cell["\<\
The rotation now is calculated  from the following expression involving the \
grade automorphism.\
\>", "Text"],

Cell[BoxData[{
    \(EvenPart[PVector[L]]/ScalarPart[PVector[B]]\), "\[IndentingNewLine]", 
    \(% /. ValueRules[B]\), "\[IndentingNewLine]", 
    \(\(\(\(\(\(\(\(% // ExpandEvenPart\) // ExpandScalarPart\) // 
                CliffordExpand\) // EvaluateBarConjugation\) // 
            EvaluateBarConjugation\) // EvaluateSuperDagger\) // 
        CliffordExpand\) // CliffordSimplify\)}], "Input"],

Cell[BoxData[
    \(Clear[B]\)], "Input"],

Cell[TextData[{
  StyleBox["Note.- This section must be evaluated sequentially only and in \
order to revaluate this section you may need to clear the values of B.",
    FontSlant->"Italic"],
  " "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Example: The Doppler Shift", "Section"],

Cell["\<\
Let's consider the case of a particle moving in the z direction emitting \
electromanetic radiation.\
\>", "Text"],

Cell["The paravelocity of the particle is:", "Text"],

Cell[BoxData[
    \(ValueRules[
        v]\  = \ \[IndentingNewLine]PVector[
          u, {0, 1}] \[Rule] \ \[Gamma] \((1 + 
              CliffordBasis[\[DoubleStruckE], {3, 1}] . {0, 0, 
                  v/c})\)\)], "Input"],

Cell["\<\
The null vector associated to the momentum of the electromagnetic radiation \
in the frame of the particle is\
\>", "Text"],

Cell[BoxData[
    \(ValueRules[
        k] = \[IndentingNewLine]PVector[
          k, {0, 1}] \[Rule] \ \[Omega]/
            c\ \((1 + 
              CliffordBasis[\[DoubleStruckE], {3, 1}] . {Sin[\[Theta]], 0, 
                  Cos[\[Theta]]})\)\)], "Input"],

Cell["\<\
where the angle is measured respect to the z axis  (the axis of the velocity \
of the particle)\
\>", "Text"],

Cell[BoxData[{
    \(ScalarPart[\((BarConjugation@PVector[u, {0, 1}] + 1)\) ** \((PVector[
              k, {0, 1}])\) ** \((BarConjugation@PVector[u, {0, 1}] + 
              1)\)]/\((2 \((1 + \[Gamma])\))\)\), "\[IndentingNewLine]", 
    \(\(\(\(\(\(\(\(\(% /. ValueRules[k]\) /. ValueRules[v] // 
                    ExpandBarConjugation\) // CliffordExpand\) // 
                BasisSimplify[\[DoubleStruckE]]\) // ExpandScalarPart\) // 
            CliffordExpand\) // CliffordExpand\) // 
        BasisSimplify[\[DoubleStruckE]]\) // 
      ExpandAll\), "\[IndentingNewLine]", 
    \(FreeDopplerEq = \((% /. v \[Rule] c*Sqrt[\[Gamma]^2 - 1]/\[Gamma])\) // 
        Simplify\)}], "Input"],

Cell["\<\
The radiation is free from Doppler effect at a particular angle.\
\>", "Text"],

Cell[BoxData[{
    \(FreeDopplerEq \[Equal] \ \((\[Omega]/c)\)\), "\[IndentingNewLine]", 
    \(\(Solve[%, Cos[\[Theta]]]\)[\([1]\)] // FullSimplify\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Example: The Doppler Shift 2nd Method", "Section"],

Cell[TextData[{
  "Another way to calculate the Doppler shift is considering the invariant: \
",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          RowBox[{"\[LeftAngleBracket]", 
            FormBox[
              RowBox[{
                FormBox[
                  TagBox[
                    StyleBox[
                      InterpretationBox["k",
                        SequenceForm[ k],
                        Editable->False],
                      FontColor->RGBColor[0.589853, 0, 0.292973],
                      Magnification->1],
                    (
                    StyleForm[ #, FontColor -> 
                      RGBColor[ .58985299999999996, 0, .29297299999999998], 
                      Magnification -> 1.0]&)],
                  "TraditionalForm"], "\[Diamond]", 
                FormBox[
                  OverscriptBox[
                    FormBox[
                      TagBox[
                        StyleBox[
                          InterpretationBox["u",
                            SequenceForm[ u],
                            Editable->False],
                          FontColor->RGBColor[0.589853, 0, 0.292973],
                          Magnification->1],
                        (
                        StyleForm[ #, FontColor -> 
                          RGBColor[ .58985299999999996, 
                            0, .29297299999999998], Magnification -> 1.0]&)],
                      "TraditionalForm"], "\<\"_\"\>"],
                  "TraditionalForm"]}],
              "TraditionalForm"], "\[RightAngleBracket]"}], "S"], 
        TraditionalForm]]],
  "\nwhich expressed in the proper frame of the particle is just the angular \
frequency divided by c\n\t",
  Cell[BoxData[
      FormBox[
        TagBox[
          StyleBox[
            FormBox[
              TagBox[
                RowBox[{
                  SubscriptBox[
                    RowBox[{"\[LeftAngleBracket]", 
                      FormBox[
                        RowBox[{
                          FormBox[
                            TagBox[
                              StyleBox[
                                InterpretationBox["k",
                                  SequenceForm[ k],
                                  Editable->False],
                                FontColor->RGBColor[0.589853, 0, 0.292973],
                                Magnification->1],
                              (
                              StyleForm[ #, FontColor -> 
                                RGBColor[ .58985299999999996, 
                                  0, .29297299999999998], Magnification -> 
                                1.0]&)],
                            "TraditionalForm"], "\[Diamond]", 
                          FormBox[
                            OverscriptBox[
                              FormBox[
                                TagBox[
                                  StyleBox[
                                    InterpretationBox["u",
                                      SequenceForm[ u],
                                      Editable->False],
                                    FontColor->RGBColor[0.589853, 0, 
                                    0.292973],
                                    Magnification->1],
                                  (
                                  StyleForm[ #, FontColor -> 
                                    RGBColor[ .58985299999999996, 
                                      0, .29297299999999998], Magnification -> 
                                    1.0]&)],
                                "TraditionalForm"], "\<\"_\"\>"],
                            "TraditionalForm"]}],
                        "TraditionalForm"], "\[RightAngleBracket]"}], "S"], 
                  "=", \(\(1\/c\) \[Omega]\_r\)}],
                DisplayForm],
              "TraditionalForm"],
            FontFamily->"Courier",
            FontSize->16],
          (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
        TraditionalForm]]]
}], "EmphasisText"],

Cell[BoxData[
    \(ScalarPart[
      PVector[k, {0, 1}] ** BarConjugation[PVector[u, {0, 1}]]]\)], "Input"],

Cell[BoxData[
    \(Clear[u]\)], "Input"],

Cell[BoxData[
    \(u /: ValueRules[
        u]\  = \ \[IndentingNewLine]PVector[
          u, {0, 1}] \[Rule] \ \[Gamma] \((1 + PVector[v, 1]/c)\)\)], "Input"],

Cell[BoxData[
    \(k /: ValueRules[
        k] = \[IndentingNewLine]PVector[
          k, {0, 1}] \[Rule] \ \[Omega]/c\ \((1 + PVector[k, 1])\)\)], "Input"],

Cell["\<\
And we get the general result relating the frequencies in the rest and moving \
frame.\
\>", "Text"],

Cell[BoxData[{
    \(c*ScalarPart[
        PVector[k, {0, 1}] ** 
          BarConjugation[PVector[u, {0, 1}]]]\), "\[IndentingNewLine]", 
    \(\(\(\(\(% /. ValueRules[u]\) /. ValueRules[k] // ExpandScalarPart\) // 
          ExpandBarConjugation\) // CliffordExpand\) // 
      CliffordSimplify\), "\[IndentingNewLine]", 
    \(\[Omega]\_r == Collect[%, \[Omega]*\[Gamma]] /. 
      a_*PVector[k, 1] ** PVector[v, 1] + 
          b_*PVector[v, 1] ** PVector[k, 1] \[Rule] \ 
        2*a*PVector[k, 1]\[CenterDot]PVector[v, 1]\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Reference", "Section"],

Cell[TextData[{
  StyleBox["William Baylis, ",
    FontSize->16],
  StyleBox["Electrodynamics. A Modern Geometric Approach",
    FontSize->16,
    FontSlant->"Italic"],
  StyleBox[", Birkhauser,2002.",
    FontSize->16]
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "Subsubtitle"],

Cell["", "Subsubtitle"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 800}, {0, 527}},
AutoGeneratedPackage->None,
WindowToolbars->{},
WindowSize->{744, 500},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
StyleDefinitions -> "TensorialStyle.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 51, 0, 76, "Title"],
Cell[1781, 54, 265, 7, 147, "Subtitle"],
Cell[2049, 63, 996, 16, 174, "Text"],
Cell[3048, 81, 74, 1, 46, "Input"],
Cell[3125, 84, 65, 1, 46, "Input"],
Cell[3193, 87, 32, 0, 34, "Text"],
Cell[3228, 89, 358, 7, 106, "Input"],

Cell[CellGroupData[{
Cell[3611, 100, 35, 0, 61, "Section"],
Cell[3649, 102, 259, 7, 54, "Text"],
Cell[3911, 111, 177, 3, 66, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[4125, 119, 37, 0, 41, "Section"],
Cell[4165, 121, 2506, 55, 80, "Text"],
Cell[6674, 178, 500, 10, 126, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[7211, 193, 38, 0, 41, "Section"],
Cell[7252, 195, 3383, 73, 60, "Text"],
Cell[10638, 270, 599, 12, 186, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[11274, 287, 25, 0, 41, "Section"],
Cell[11302, 289, 2579, 56, 80, "Text"],
Cell[13884, 347, 491, 10, 126, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[14412, 362, 42, 0, 41, "Section"],

Cell[CellGroupData[{
Cell[14479, 366, 100, 2, 49, "Subsection"],
Cell[14582, 370, 10094, 201, 66, "Text"],
Cell[24679, 573, 33, 0, 34, "Text"],
Cell[24715, 575, 377, 6, 146, "Input"],
Cell[25095, 583, 42, 0, 34, "Text"],
Cell[25140, 585, 362, 8, 126, "Input"],
Cell[25505, 595, 48, 0, 34, "Text"],
Cell[25556, 597, 327, 5, 126, "Input"],
Cell[25886, 604, 91, 2, 34, "Text"],
Cell[25980, 608, 62, 1, 46, "Input"],
Cell[26045, 611, 5528, 106, 87, "Text"],
Cell[31576, 719, 753, 13, 246, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[32366, 737, 118, 3, 70, "Subsection"],
Cell[32487, 742, 46, 0, 34, "Text"],
Cell[32536, 744, 209, 4, 106, "Input"],
Cell[32748, 750, 1369, 36, 34, "Text"],
Cell[34120, 788, 764, 13, 246, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[34933, 807, 44, 0, 41, "Section"],
Cell[34980, 809, 3494, 87, 88, "EmphasisText"],
Cell[38477, 898, 139, 3, 46, "Input"],
Cell[38619, 903, 76, 1, 46, "Input"],
Cell[38698, 906, 774, 24, 35, "Text"],
Cell[39475, 932, 292, 5, 86, "Input"],
Cell[39770, 939, 1502, 44, 35, "Text"],
Cell[41275, 985, 559, 10, 126, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[41871, 1000, 62, 0, 41, "Section"],
Cell[41936, 1002, 64, 0, 34, "Text"],
Cell[42003, 1004, 41, 1, 46, "Input"],
Cell[42047, 1007, 257, 6, 66, "Input"],
Cell[42307, 1015, 111, 3, 34, "Text"],
Cell[42421, 1020, 243, 4, 86, "Input"],
Cell[42667, 1026, 170, 5, 35, "Text"],
Cell[42840, 1033, 146, 3, 34, "Text"],
Cell[42989, 1038, 444, 7, 126, "Input"],
Cell[43436, 1047, 64, 0, 34, "Text"],
Cell[43503, 1049, 395, 7, 106, "Input"],
Cell[43901, 1058, 57, 0, 34, "Text"],
Cell[43961, 1060, 278, 4, 106, "Input"],
Cell[44242, 1066, 121, 3, 34, "Text"],
Cell[44366, 1071, 401, 6, 126, "Input"],
Cell[44770, 1079, 41, 1, 46, "Input"],
Cell[44814, 1082, 209, 5, 54, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[45060, 1092, 45, 0, 41, "Section"],
Cell[45108, 1094, 124, 3, 34, "Text"],
Cell[45235, 1099, 52, 0, 34, "Text"],
Cell[45290, 1101, 227, 5, 66, "Input"],
Cell[45520, 1108, 133, 3, 34, "Text"],
Cell[45656, 1113, 261, 6, 66, "Input"],
Cell[45920, 1121, 119, 3, 34, "Text"],
Cell[46042, 1126, 694, 11, 146, "Input"],
Cell[46739, 1139, 88, 2, 34, "Text"],
Cell[46830, 1143, 162, 2, 66, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[47029, 1150, 56, 0, 41, "Section"],
Cell[47088, 1152, 4054, 93, 101, "EmphasisText"],
Cell[51145, 1247, 108, 2, 46, "Input"],
Cell[51256, 1251, 41, 1, 46, "Input"],
Cell[51300, 1254, 160, 3, 66, "Input"],
Cell[51463, 1259, 157, 3, 66, "Input"],
Cell[51623, 1264, 110, 3, 34, "Text"],
Cell[51736, 1269, 541, 10, 146, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[52314, 1284, 28, 0, 41, "Section"],
Cell[52345, 1286, 231, 8, 37, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[52613, 1299, 23, 0, 43, "Subsubtitle"],
Cell[52639, 1301, 23, 0, 43, "Subsubtitle"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

