(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      7223,        257]*)
(*NotebookOutlinePosition[      8229,        292]*)
(*  CellTagsIndexPosition[      8155,        286]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Wedge Product (\[Wedge])", "ObjectName",
  CellTags->"Function?"],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  Cell[BoxData[
      RowBox[{"Wedge", 
        StyleBox["[",
          "MR"], 
        RowBox[{
          StyleBox["p",
            "MR"], 
          StyleBox[",",
            "TI"], 
          StyleBox["q",
            "TI"], 
          StyleBox[",",
            "TI"], 
          StyleBox[" ",
            "TI"], 
          StyleBox[\(r ... \),
            "TI"]}], 
        StyleBox["]",
          "MR"]}]]],
  "represents the wedge product of PVector objects p, q, r..."
}], "Usage",
  CellTags->"Function?"],

Cell[TextData[{
  " The Wedge Product overloads the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " operator \[Wedge]"
}], "MathCaption"],

Cell[TextData[{
  "See also: ",
  ButtonBox["CliffordInnerProduct",
    ButtonData:>{"InnerProduct", None},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["GeometricProduct",
    ButtonData:>{"GeometricProduct", None},
    ButtonStyle->"AddOnsLink"],
  " , ",
  ButtonBox["PVector",
    ButtonData:>{"PVector", None},
    ButtonStyle->"AddOnsLink"]
}], "MathCaption"],

Cell[CellGroupData[{

Cell["Examples", "ExampleSection"],

Cell[BoxData[
    \(Needs["\<TCliffordAlgebra1`TClifford`\>"]\)], "Input",
  CellLabel->"In[1]:="],

Cell["The wedge product of two vectors is:", "Text"],

Cell[BoxData[
    \(Wedge[PVector[v], PVector[w]]\)], "Input",
  CellLabel->"In[2]:="],

Cell["Or simply", "Text"],

Cell[BoxData[
    \(PVector[v]\[Wedge]PVector[w]\)], "Input",
  CellLabel->"In[3]:="],

Cell["The wedge product is associative. ", "Text"],

Cell[BoxData[{
    \(Wedge[\ \ Wedge[PVector[u], PVector[v]]\ , 
      PVector[w]]\), "\[IndentingNewLine]", 
    \(% // FullForm\)}], "Input",
  CellLabel->"In[4]:="],

Cell["\<\
Scalars are pulled out of the wedge product with WedgeSimplify. In general we \
denote scalars with greek letters.\
\>", "Text"],

Cell[BoxData[{
    \(\((PVector[\[Alpha], 0]*PVector[v, 1])\)\[Wedge]PVector[w, 
        1]\), "\[IndentingNewLine]", 
    \(WedgeSimplify[%]\)}], "Input",
  CellLabel->"In[6]:="],

Cell[BoxData[{
    \(\((PVector[\[Alpha], 
            0]*\((PVector[v, 1] + PVector[u, 1])\))\)\[Wedge]PVector[w, 
        1]\), "\[IndentingNewLine]", 
    \(WedgeSimplify[%]\)}], "Input",
  CellLabel->"In[8]:="],

Cell[BoxData[{
    \(\((f[x]*PVector[v, 1])\)\[Wedge]PVector[w, 
        1]\), "\[IndentingNewLine]", 
    \(WedgeSimplify[%]\)}], "Input",
  CellLabel->"In[10]:="],

Cell[BoxData[{
    \(PVector[v, 
        1]\[Wedge]\((PVector[w, 1] PVector[\[Alpha], 0])\)\[Wedge]PVector[u, 
        1]\), "\[IndentingNewLine]", 
    \(WedgeSimplify[%]\)}], "Input",
  CellLabel->"In[12]:="],

Cell[BoxData[{
    \(Wedge[PVector[v, 1], \[Pi]*PVector[w, 1], 
      PVector[u, 1]]\), "\[IndentingNewLine]", 
    \(WedgeSimplify[%]\)}], "Input",
  CellLabel->"In[14]:="],

Cell["The wedge of a vector with itself is zero:", "Text"],

Cell[BoxData[
    \(Wedge[PVector[w], PVector[w]]\)], "Input",
  CellLabel->"In[16]:="],

Cell["\<\
If two vectors appear anywhere in the product the result is zero but we need \
WedgeSimplify\
\>", "Text"],

Cell[BoxData[{
    \(Wedge[PVector[w], PVector[v], PVector[w]]\), "\[IndentingNewLine]", 
    \(WedgeSimplify[%]\)}], "Input",
  CellLabel->"In[17]:="],

Cell[BoxData[{
    \(Wedge[PVector[w], k, PVector[u]]\), "\[IndentingNewLine]", 
    \(WedgeSimplify[%]\)}], "Input",
  CellLabel->"In[19]:="],

Cell[BoxData[{
    \(Wedge[PVector[w], PVector[q, 0]]\), "\[IndentingNewLine]", 
    \(WedgeSimplify[%]\)}], "Input",
  CellLabel->"In[21]:="],

Cell["If one of the vectors is just a scalar the result is zero.", "Text"],

Cell[BoxData[{
    \(Wedge[PVector[w], PVector[v, 0], PVector[u]]\), "\[IndentingNewLine]", 
    \(WedgeSimplify[%]\)}], "Input",
  CellLabel->"In[27]:="],

Cell["The wedge product is distributed over the sum ", "Text"],

Cell[BoxData[{
    \(PVector[u, 
        1]\[Wedge]\((PVector[v, 1] + 
          PVector[w, 1])\)\), "\[IndentingNewLine]", 
    \(% // CliffordExpand\)}], "Input",
  CellLabel->"In[29]:="],

Cell[BoxData[{
    \(\((PVector[u, 1] + PVector[v, 1])\)\[Wedge]\((PVector[w, 1] + 
          PVector[z, 1])\)\), "\[IndentingNewLine]", 
    \(% // CliffordExpand\)}], "Input",
  CellLabel->"In[31]:="],

Cell[BoxData[{
    \(\((PVector[u] + PVector[v])\)\[Wedge]\((PVector[w] + 
          PVector[z])\)\), "\[IndentingNewLine]", 
    \(% // CliffordExpand\)}], "Input",
  CellLabel->"In[33]:="],

Cell["\<\
Anticommutative between first order vectors.We use SortWedgeC1 to sort first \
order vectors.\
\>", "Text"],

Cell[BoxData[{
    \(Wedge[PVector[w, 1], PVector[v, 1], 
      PVector[u, 1]]\), "\[IndentingNewLine]", 
    \(SortWedgeC1[%]\)}], "Input",
  CellLabel->"In[35]:="],

Cell["\<\
SortWedgeC1 must be used when all the vectors are first order because of time \
efficiency. 

Alternatively we use SortWedge to sort the wedge product where each vector \
may be of any grade.\
\>", "Text"],

Cell[BoxData[{
    \(Wedge[PVector[w, 1], PVector[v, 1], 
      PVector[u, 1]]\), "\[IndentingNewLine]", 
    \(SortWedge[%]\)}], "Input",
  CellLabel->"In[37]:="],

Cell[BoxData[{
    \(Wedge[PVector[w, 1], PVector[v, 2], 
      PVector[u, 1]]\), "\[IndentingNewLine]", 
    \(SortWedge[%]\)}], "Input",
  CellLabel->"In[39]:="],

Cell[BoxData[{
    \(Wedge[PVector[u, 1], PVector[w, 2], 
      PVector[v, 1]]\), "\[IndentingNewLine]", 
    \(SortWedge[%]\)}], "Input",
  CellLabel->"In[41]:="]
}, Closed]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 800}, {0, 527}},
ScreenStyleEnvironment->"Working",
WindowToolbars->{},
WindowSize->{653, 500},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
ShowSelection->True,
CommonDefaultFormatTypes->{"Output"->TraditionalForm},
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Function?"->{
    Cell[1705, 50, 71, 1, 31, "ObjectName",
      CellTags->"Function?"],
    Cell[1779, 53, 556, 23, 32, "Usage",
      CellTags->"Function?"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Function?", 7984, 277}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1705, 50, 71, 1, 31, "ObjectName",
  CellTags->"Function?"],
Cell[1779, 53, 556, 23, 32, "Usage",
  CellTags->"Function?"],
Cell[2338, 78, 148, 5, 31, "MathCaption"],
Cell[2489, 85, 372, 13, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[2886, 102, 34, 0, 40, "ExampleSection"],
Cell[2923, 104, 98, 2, 29, "Input"],
Cell[3024, 108, 52, 0, 25, "Text"],
Cell[3079, 110, 86, 2, 29, "Input"],
Cell[3168, 114, 25, 0, 25, "Text"],
Cell[3196, 116, 85, 2, 29, "Input"],
Cell[3284, 120, 50, 0, 25, "Text"],
Cell[3337, 122, 167, 4, 49, "Input"],
Cell[3507, 128, 138, 3, 25, "Text"],
Cell[3648, 133, 179, 4, 49, "Input"],
Cell[3830, 139, 214, 5, 49, "Input"],
Cell[4047, 146, 164, 4, 49, "Input"],
Cell[4214, 152, 210, 5, 49, "Input"],
Cell[4427, 159, 173, 4, 49, "Input"],
Cell[4603, 165, 58, 0, 25, "Text"],
Cell[4664, 167, 87, 2, 29, "Input"],
Cell[4754, 171, 116, 3, 25, "Text"],
Cell[4873, 176, 151, 3, 49, "Input"],
Cell[5027, 181, 142, 3, 49, "Input"],
Cell[5172, 186, 142, 3, 49, "Input"],
Cell[5317, 191, 74, 0, 25, "Text"],
Cell[5394, 193, 154, 3, 49, "Input"],
Cell[5551, 198, 62, 0, 25, "Text"],
Cell[5616, 200, 189, 5, 49, "Input"],
Cell[5808, 207, 202, 4, 49, "Input"],
Cell[6013, 213, 190, 4, 49, "Input"],
Cell[6206, 219, 117, 3, 25, "Text"],
Cell[6326, 224, 165, 4, 49, "Input"],
Cell[6494, 230, 215, 6, 75, "Text"],
Cell[6712, 238, 163, 4, 49, "Input"],
Cell[6878, 244, 163, 4, 49, "Input"],
Cell[7044, 250, 163, 4, 49, "Input"]
}, Closed]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

